# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/api/trading.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .. import vega_pb2 as proto_dot_vega__pb2
from .. import markets_pb2 as proto_dot_markets__pb2
from .. import governance_pb2 as proto_dot_governance__pb2
from .. import chain_events_pb2 as proto_dot_chain__events__pb2
from .. import assets_pb2 as proto_dot_assets__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from .. import mwitkow_goprotovalidators_validator_pb2 as github_dot_com_dot_mwitkow_dot_go__proto__validators_dot_validator__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/api/trading.proto',
  package='api',
  syntax='proto3',
  serialized_options=b'Z#code.vegaprotocol.io/vega/proto/api',
  serialized_pb=b'\n\x17proto/api/trading.proto\x12\x03\x61pi\x1a\x10proto/vega.proto\x1a\x13proto/markets.proto\x1a\x16proto/governance.proto\x1a\x18proto/chain_events.proto\x1a\x12proto/assets.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x36github.com/mwitkow/go-proto-validators/validator.proto\";\n\x1aPropagateChainEventRequest\x12\x1d\n\x03\x65vt\x18\x01 \x01(\x0b\x32\x10.vega.ChainEvent\".\n\x1bPropagateChainEventResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\":\n\x18SubmitTransactionRequest\x12\x1e\n\x02tx\x18\x01 \x01(\x0b\x32\x12.vega.SignedBundle\",\n\x19SubmitTransactionResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"3\n\x0fWithdrawRequest\x12 \n\x08withdraw\x18\x01 \x01(\x0b\x32\x0e.vega.Withdraw\"#\n\x10WithdrawResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"F\n\x1aNotifyTraderAccountRequest\x12(\n\x05notif\x18\x01 \x01(\x0b\x32\x19.vega.NotifyTraderAccount\"0\n\x1bNotifyTraderAccountResponse\x12\x11\n\tsubmitted\x18\x01 \x01(\x08\"<\n\x1aPrepareSubmitOrderResponse\x12\x0c\n\x04\x62lob\x18\x01 \x01(\x0c\x12\x10\n\x08submitID\x18\x02 \x01(\t\"*\n\x1aPrepareCancelOrderResponse\x12\x0c\n\x04\x62lob\x18\x01 \x01(\x0c\")\n\x19PrepareAmendOrderResponse\x12\x0c\n\x04\x62lob\x18\x01 \x01(\x0c\"?\n\x12SubmitOrderRequest\x12)\n\nsubmission\x18\x01 \x01(\x0b\x32\x15.vega.OrderSubmission\"C\n\x12\x43\x61ncelOrderRequest\x12-\n\x0c\x63\x61ncellation\x18\x01 \x01(\x0b\x32\x17.vega.OrderCancellation\"<\n\x11\x41mendOrderRequest\x12\'\n\tamendment\x18\x01 \x01(\x0b\x32\x14.vega.OrderAmendment\"\x0f\n\rAssetsRequest\"-\n\x0e\x41ssetsResponse\x12\x1b\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x0b.vega.Asset\"\x1e\n\x10\x41ssetByIDRequest\x12\n\n\x02ID\x18\x01 \x01(\t\"/\n\x11\x41ssetByIDResponse\x12\x1a\n\x05\x61sset\x18\x01 \x01(\x0b\x32\x0b.vega.Asset\"/\n!GetNodeSignaturesAggregateRequest\x12\n\n\x02ID\x18\x01 \x01(\t\"M\n\"GetNodeSignaturesAggregateResponse\x12\'\n\nsignatures\x18\x01 \x03(\x0b\x32\x13.vega.NodeSignature\"<\n\x15OptionalProposalState\x12#\n\x05value\x18\x01 \x01(\x0e\x32\x14.vega.Proposal.State\"H\n\x13GetProposalsRequest\x12\x31\n\rselectInState\x18\x01 \x01(\x0b\x32\x1a.api.OptionalProposalState\":\n\x14GetProposalsResponse\x12\"\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x14.vega.GovernanceData\"h\n\x1aGetProposalsByPartyRequest\x12\x17\n\x07partyID\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01\x12\x31\n\rselectInState\x18\x02 \x01(\x0b\x32\x1a.api.OptionalProposalState\"A\n\x1bGetProposalsByPartyResponse\x12\"\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x14.vega.GovernanceData\"1\n\x16GetVotesByPartyRequest\x12\x17\n\x07partyID\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01\"4\n\x17GetVotesByPartyResponse\x12\x19\n\x05votes\x18\x01 \x03(\x0b\x32\n.vega.Vote\"Q\n\x1cGetNewMarketProposalsRequest\x12\x31\n\rselectInState\x18\x01 \x01(\x0b\x32\x1a.api.OptionalProposalState\"C\n\x1dGetNewMarketProposalsResponse\x12\"\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x14.vega.GovernanceData\"n\n\x1fGetUpdateMarketProposalsRequest\x12\x18\n\x08marketID\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01\x12\x31\n\rselectInState\x18\x02 \x01(\x0b\x32\x1a.api.OptionalProposalState\"F\n GetUpdateMarketProposalsResponse\x12\"\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x14.vega.GovernanceData\"Y\n$GetNetworkParametersProposalsRequest\x12\x31\n\rselectInState\x18\x01 \x01(\x0b\x32\x1a.api.OptionalProposalState\"K\n%GetNetworkParametersProposalsResponse\x12\"\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x14.vega.GovernanceData\"P\n\x1bGetNewAssetProposalsRequest\x12\x31\n\rselectInState\x18\x01 \x01(\x0b\x32\x1a.api.OptionalProposalState\"B\n\x1cGetNewAssetProposalsResponse\x12\"\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x14.vega.GovernanceData\"4\n\x16GetProposalByIDRequest\x12\x1a\n\nproposalID\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01\"=\n\x17GetProposalByIDResponse\x12\"\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x14.vega.GovernanceData\":\n\x1dGetProposalByReferenceRequest\x12\x19\n\tReference\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01\"D\n\x1eGetProposalByReferenceResponse\x12\"\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x14.vega.GovernanceData\"7\n\x1cObservePartyProposalsRequest\x12\x17\n\x07partyID\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01\"9\n\x1bObserveProposalVotesRequest\x12\x1a\n\nproposalID\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01\"3\n\x18ObservePartyVotesRequest\x12\x17\n\x07partyID\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01\"I\n\x1cMarginLevelsSubscribeRequest\x12\x17\n\x07partyID\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01\x12\x10\n\x08marketID\x18\x02 \x01(\t\"@\n\x13MarginLevelsRequest\x12\x17\n\x07partyID\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01\x12\x10\n\x08marketID\x18\x02 \x01(\t\"@\n\x14MarginLevelsResponse\x12(\n\x0cmarginLevels\x18\x01 \x03(\x0b\x32\x12.vega.MarginLevels\"/\n\x1bMarketsDataSubscribeRequest\x12\x10\n\x08marketID\x18\x01 \x01(\t\"1\n\x15MarketDataByIDRequest\x12\x18\n\x08marketID\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01\">\n\x16MarketDataByIDResponse\x12$\n\nmarketData\x18\x01 \x01(\x0b\x32\x10.vega.MarketData\"<\n\x13MarketsDataResponse\x12%\n\x0bmarketsData\x18\x01 \x03(\x0b\x32\x10.vega.MarketData\",\n\x10LastTradeRequest\x12\x18\n\x08marketID\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01\"/\n\x11LastTradeResponse\x12\x1a\n\x05trade\x18\x01 \x01(\x0b\x32\x0b.vega.Trade\"-\n\x11MarketByIDRequest\x12\x18\n\x08marketID\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01\"2\n\x12MarketByIDResponse\x12\x1c\n\x06market\x18\x01 \x01(\x0b\x32\x0c.vega.Market\"+\n\x10PartyByIDRequest\x12\x17\n\x07partyID\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01\"/\n\x11PartyByIDResponse\x12\x1a\n\x05party\x18\x01 \x01(\x0b\x32\x0b.vega.Party\"/\n\x0fPartiesResponse\x12\x1c\n\x07parties\x18\x01 \x03(\x0b\x32\x0b.vega.Party\"^\n\x14TradesByPartyRequest\x12\x0f\n\x07partyID\x18\x01 \x01(\t\x12\x10\n\x08marketID\x18\x02 \x01(\t\x12#\n\npagination\x18\x03 \x01(\x0b\x32\x0f.api.Pagination\"4\n\x15TradesByPartyResponse\x12\x1b\n\x06trades\x18\x01 \x03(\x0b\x32\x0b.vega.Trade\"\'\n\x14TradesByOrderRequest\x12\x0f\n\x07orderID\x18\x01 \x01(\t\"4\n\x15TradesByOrderResponse\x12\x1b\n\x06trades\x18\x01 \x03(\x0b\x32\x0b.vega.Trade\"m\n\x18\x41\x63\x63ountsSubscribeRequest\x12\x10\n\x08marketID\x18\x01 \x01(\t\x12\x0f\n\x07partyID\x18\x02 \x01(\t\x12\r\n\x05\x61sset\x18\x03 \x01(\t\x12\x1f\n\x04type\x18\x04 \x01(\x0e\x32\x11.vega.AccountType\";\n\x16OrdersSubscribeRequest\x12\x10\n\x08marketID\x18\x01 \x01(\t\x12\x0f\n\x07partyID\x18\x02 \x01(\t\";\n\x16TradesSubscribeRequest\x12\x10\n\x08marketID\x18\x01 \x01(\t\x12\x0f\n\x07partyID\x18\x02 \x01(\t\"U\n\x17\x43\x61ndlesSubscribeRequest\x12\x18\n\x08marketID\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01\x12 \n\x08interval\x18\x02 \x01(\x0e\x32\x0e.vega.Interval\"7\n\x1bMarketDepthSubscribeRequest\x12\x18\n\x08marketID\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01\",\n\x19PositionsSubscribeRequest\x12\x0f\n\x07partyID\x18\x01 \x01(\t\"V\n\x15OrdersByMarketRequest\x12\x18\n\x08marketID\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01\x12#\n\npagination\x18\x02 \x01(\x0b\x32\x0f.api.Pagination\"5\n\x16OrdersByMarketResponse\x12\x1b\n\x06orders\x18\x01 \x03(\x0b\x32\x0b.vega.Order\"T\n\x14OrdersByPartyRequest\x12\x17\n\x07partyID\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01\x12#\n\npagination\x18\x02 \x01(\x0b\x32\x0f.api.Pagination\"4\n\x15OrdersByPartyResponse\x12\x1b\n\x06orders\x18\x01 \x03(\x0b\x32\x0b.vega.Order\"N\n\x19OrderByMarketAndIdRequest\x12\x18\n\x08marketID\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01\x12\x17\n\x07orderID\x18\x02 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01\"8\n\x1aOrderByMarketAndIdResponse\x12\x1a\n\x05order\x18\x01 \x01(\x0b\x32\x0b.vega.Order\"4\n\x17OrderByReferenceRequest\x12\x19\n\treference\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01\"6\n\x18OrderByReferenceResponse\x12\x1a\n\x05order\x18\x01 \x01(\x0b\x32\x0b.vega.Order\"0\n\x0fMarketsResponse\x12\x1d\n\x07markets\x18\x01 \x03(\x0b\x32\x0c.vega.Market\"l\n\x0e\x43\x61ndlesRequest\x12\x18\n\x08marketID\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01\x12\x1e\n\x0esinceTimestamp\x18\x02 \x01(\x03\x42\x06\xe2\xdf\x1f\x02\x10\x00\x12 \n\x08interval\x18\x03 \x01(\x0e\x32\x0e.vega.Interval\"0\n\x0f\x43\x61ndlesResponse\x12\x1d\n\x07\x63\x61ndles\x18\x01 \x03(\x0b\x32\x0c.vega.Candle\"@\n\x12MarketDepthRequest\x12\x18\n\x08marketID\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01\x12\x10\n\x08maxDepth\x18\x02 \x01(\x04\"\x86\x01\n\x13MarketDepthResponse\x12\x10\n\x08marketID\x18\x01 \x01(\t\x12\x1d\n\x03\x62uy\x18\x02 \x03(\x0b\x32\x10.vega.PriceLevel\x12\x1e\n\x04sell\x18\x03 \x03(\x0b\x32\x10.vega.PriceLevel\x12\x1e\n\tlastTrade\x18\x04 \x01(\x0b\x32\x0b.vega.Trade\"V\n\x15TradesByMarketRequest\x12\x18\n\x08marketID\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01\x12#\n\npagination\x18\x02 \x01(\x0b\x32\x0f.api.Pagination\"5\n\x16TradesByMarketResponse\x12\x1b\n\x06trades\x18\x01 \x03(\x0b\x32\x0b.vega.Trade\"D\n\x17PositionsByPartyRequest\x12\x17\n\x07partyID\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01\x12\x10\n\x08marketID\x18\x02 \x01(\t\"=\n\x18PositionsByPartyResponse\x12!\n\tpositions\x18\x01 \x03(\x0b\x32\x0e.vega.Position\"%\n\x10VegaTimeResponse\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\"=\n\nPagination\x12\x0c\n\x04skip\x18\x01 \x01(\x04\x12\r\n\x05limit\x18\x02 \x01(\x04\x12\x12\n\ndescending\x18\x03 \x01(\x08\"+\n\x0cOrdersStream\x12\x1b\n\x06orders\x18\x01 \x03(\x0b\x32\x0b.vega.Order\"+\n\x0cTradesStream\x12\x1b\n\x06trades\x18\x01 \x03(\x0b\x32\x0b.vega.Trade\"i\n\x14PartyAccountsRequest\x12\x0f\n\x07partyID\x18\x01 \x01(\t\x12\x10\n\x08marketID\x18\x02 \x01(\t\x12\x1f\n\x04type\x18\x03 \x01(\x0e\x32\x11.vega.AccountType\x12\r\n\x05\x61sset\x18\x04 \x01(\t\"8\n\x15PartyAccountsResponse\x12\x1f\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32\r.vega.Account\"8\n\x15MarketAccountsRequest\x12\x10\n\x08marketID\x18\x01 \x01(\t\x12\r\n\x05\x61sset\x18\x02 \x01(\t\"9\n\x16MarketAccountsResponse\x12\x1f\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32\r.vega.Account\"s\n\x16PrepareProposalRequest\x12\x17\n\x07partyID\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01\x12\x11\n\treference\x18\x02 \x01(\t\x12-\n\x08proposal\x18\x03 \x01(\x0b\x32\x13.vega.ProposalTermsB\x06\xe2\xdf\x1f\x02 \x01\"P\n\x17PrepareProposalResponse\x12\x0c\n\x04\x62lob\x18\x01 \x01(\x0c\x12\'\n\x0fpendingProposal\x18\x02 \x01(\x0b\x32\x0e.vega.Proposal\"6\n\x12PrepareVoteRequest\x12 \n\x04vote\x18\x01 \x01(\x0b\x32\n.vega.VoteB\x06\xe2\xdf\x1f\x02 \x01\"=\n\x13PrepareVoteResponse\x12\x0c\n\x04\x62lob\x18\x01 \x01(\x0c\x12\x18\n\x04vote\x18\x02 \x01(\x0b\x32\n.vega.Vote\"<\n\x10OrderByIDRequest\x12\x17\n\x07orderID\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02 \x01\x12\x0f\n\x07version\x18\x02 \x01(\x04\"8\n\x19OrderByReferenceIDRequest\x12\x1b\n\x0breferenceID\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02 \x01\"X\n\x18OrderVersionsByIDRequest\x12\x17\n\x07orderID\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02 \x01\x12#\n\npagination\x18\x02 \x01(\x0b\x32\x0f.api.Pagination\"4\n\x15OrderVersionsResponse\x12\x1b\n\x06orders\x18\x01 \x03(\x0b\x32\x0b.vega.Order2\xc7\x05\n\x07trading\x12N\n\x12PrepareSubmitOrder\x12\x17.api.SubmitOrderRequest\x1a\x1f.api.PrepareSubmitOrderResponse\x12N\n\x12PrepareCancelOrder\x12\x17.api.CancelOrderRequest\x1a\x1f.api.PrepareCancelOrderResponse\x12K\n\x11PrepareAmendOrder\x12\x16.api.AmendOrderRequest\x1a\x1e.api.PrepareAmendOrderResponse\x12X\n\x13NotifyTraderAccount\x12\x1f.api.NotifyTraderAccountRequest\x1a .api.NotifyTraderAccountResponse\x12\x37\n\x08Withdraw\x12\x14.api.WithdrawRequest\x1a\x15.api.WithdrawResponse\x12R\n\x11SubmitTransaction\x12\x1d.api.SubmitTransactionRequest\x1a\x1e.api.SubmitTransactionResponse\x12L\n\x0fPrepareProposal\x12\x1b.api.PrepareProposalRequest\x1a\x1c.api.PrepareProposalResponse\x12@\n\x0bPrepareVote\x12\x17.api.PrepareVoteRequest\x1a\x18.api.PrepareVoteResponse\x12X\n\x13PropagateChainEvent\x12\x1f.api.PropagateChainEventRequest\x1a .api.PropagateChainEventResponse2\x89\x1d\n\x0ctrading_data\x12I\n\x0eMarketAccounts\x12\x1a.api.MarketAccountsRequest\x1a\x1b.api.MarketAccountsResponse\x12\x46\n\rPartyAccounts\x12\x19.api.PartyAccountsRequest\x1a\x1a.api.PartyAccountsResponse\x12\x34\n\x07\x43\x61ndles\x12\x13.api.CandlesRequest\x1a\x14.api.CandlesResponse\x12I\n\x0eMarketDataByID\x12\x1a.api.MarketDataByIDRequest\x1a\x1b.api.MarketDataByIDResponse\x12?\n\x0bMarketsData\x12\x16.google.protobuf.Empty\x1a\x18.api.MarketsDataResponse\x12=\n\nMarketByID\x12\x16.api.MarketByIDRequest\x1a\x17.api.MarketByIDResponse\x12@\n\x0bMarketDepth\x12\x17.api.MarketDepthRequest\x1a\x18.api.MarketDepthResponse\x12\x37\n\x07Markets\x12\x16.google.protobuf.Empty\x1a\x14.api.MarketsResponse\x12U\n\x12OrderByMarketAndID\x12\x1e.api.OrderByMarketAndIdRequest\x1a\x1f.api.OrderByMarketAndIdResponse\x12O\n\x10OrderByReference\x12\x1c.api.OrderByReferenceRequest\x1a\x1d.api.OrderByReferenceResponse\x12I\n\x0eOrdersByMarket\x12\x1a.api.OrdersByMarketRequest\x1a\x1b.api.OrdersByMarketResponse\x12\x46\n\rOrdersByParty\x12\x19.api.OrdersByPartyRequest\x1a\x1a.api.OrdersByPartyResponse\x12/\n\tOrderByID\x12\x15.api.OrderByIDRequest\x1a\x0b.vega.Order\x12\x41\n\x12OrderByReferenceID\x12\x1e.api.OrderByReferenceIDRequest\x1a\x0b.vega.Order\x12N\n\x11OrderVersionsByID\x12\x1d.api.OrderVersionsByIDRequest\x1a\x1a.api.OrderVersionsResponse\x12\x43\n\x0cMarginLevels\x12\x18.api.MarginLevelsRequest\x1a\x19.api.MarginLevelsResponse\x12\x37\n\x07Parties\x12\x16.google.protobuf.Empty\x1a\x14.api.PartiesResponse\x12:\n\tPartyByID\x12\x15.api.PartyByIDRequest\x1a\x16.api.PartyByIDResponse\x12O\n\x10PositionsByParty\x12\x1c.api.PositionsByPartyRequest\x1a\x1d.api.PositionsByPartyResponse\x12:\n\tLastTrade\x12\x15.api.LastTradeRequest\x1a\x16.api.LastTradeResponse\x12I\n\x0eTradesByMarket\x12\x1a.api.TradesByMarketRequest\x1a\x1b.api.TradesByMarketResponse\x12\x46\n\rTradesByOrder\x12\x19.api.TradesByOrderRequest\x1a\x1a.api.TradesByOrderResponse\x12\x46\n\rTradesByParty\x12\x19.api.TradesByPartyRequest\x1a\x1a.api.TradesByPartyResponse\x12\x43\n\x0cGetProposals\x12\x18.api.GetProposalsRequest\x1a\x19.api.GetProposalsResponse\x12X\n\x13GetProposalsByParty\x12\x1f.api.GetProposalsByPartyRequest\x1a .api.GetProposalsByPartyResponse\x12L\n\x0fGetVotesByParty\x12\x1b.api.GetVotesByPartyRequest\x1a\x1c.api.GetVotesByPartyResponse\x12^\n\x15GetNewMarketProposals\x12!.api.GetNewMarketProposalsRequest\x1a\".api.GetNewMarketProposalsResponse\x12g\n\x18GetUpdateMarketProposals\x12$.api.GetUpdateMarketProposalsRequest\x1a%.api.GetUpdateMarketProposalsResponse\x12v\n\x1dGetNetworkParametersProposals\x12).api.GetNetworkParametersProposalsRequest\x1a*.api.GetNetworkParametersProposalsResponse\x12[\n\x14GetNewAssetProposals\x12 .api.GetNewAssetProposalsRequest\x1a!.api.GetNewAssetProposalsResponse\x12L\n\x0fGetProposalByID\x12\x1b.api.GetProposalByIDRequest\x1a\x1c.api.GetProposalByIDResponse\x12\x61\n\x16GetProposalByReference\x12\".api.GetProposalByReferenceRequest\x1a#.api.GetProposalByReferenceResponse\x12\x43\n\x11ObserveGovernance\x12\x16.google.protobuf.Empty\x1a\x14.vega.GovernanceData0\x01\x12R\n\x15ObservePartyProposals\x12!.api.ObservePartyProposalsRequest\x1a\x14.vega.GovernanceData0\x01\x12@\n\x11ObservePartyVotes\x12\x1d.api.ObservePartyVotesRequest\x1a\n.vega.Vote0\x01\x12\x46\n\x14ObserveProposalVotes\x12 .api.ObserveProposalVotesRequest\x1a\n.vega.Vote0\x01\x12\x36\n\nStatistics\x12\x16.google.protobuf.Empty\x1a\x10.vega.Statistics\x12<\n\x0bGetVegaTime\x12\x16.google.protobuf.Empty\x1a\x15.api.VegaTimeResponse\x12\x43\n\x11\x41\x63\x63ountsSubscribe\x12\x1d.api.AccountsSubscribeRequest\x1a\r.vega.Account0\x01\x12@\n\x10\x43\x61ndlesSubscribe\x12\x1c.api.CandlesSubscribeRequest\x1a\x0c.vega.Candle0\x01\x12P\n\x15MarginLevelsSubscribe\x12!.api.MarginLevelsSubscribeRequest\x1a\x12.vega.MarginLevels0\x01\x12M\n\x14MarketDepthSubscribe\x12 .api.MarketDepthSubscribeRequest\x1a\x11.vega.MarketDepth0\x01\x12L\n\x14MarketsDataSubscribe\x12 .api.MarketsDataSubscribeRequest\x1a\x10.vega.MarketData0\x01\x12\x43\n\x0fOrdersSubscribe\x12\x1b.api.OrdersSubscribeRequest\x1a\x11.api.OrdersStream0\x01\x12\x46\n\x12PositionsSubscribe\x12\x1e.api.PositionsSubscribeRequest\x1a\x0e.vega.Position0\x01\x12\x43\n\x0fTradesSubscribe\x12\x1b.api.TradesSubscribeRequest\x1a\x11.api.TradesStream0\x01\x12N\n\x1aTransferResponsesSubscribe\x12\x16.google.protobuf.Empty\x1a\x16.vega.TransferResponse0\x01\x12m\n\x1aGetNodeSignaturesAggregate\x12&.api.GetNodeSignaturesAggregateRequest\x1a\'.api.GetNodeSignaturesAggregateResponse\x12:\n\tAssetByID\x12\x15.api.AssetByIDRequest\x1a\x16.api.AssetByIDResponse\x12\x31\n\x06\x41ssets\x12\x12.api.AssetsRequest\x1a\x13.api.AssetsResponseB%Z#code.vegaprotocol.io/vega/proto/apib\x06proto3'
  ,
  dependencies=[proto_dot_vega__pb2.DESCRIPTOR,proto_dot_markets__pb2.DESCRIPTOR,proto_dot_governance__pb2.DESCRIPTOR,proto_dot_chain__events__pb2.DESCRIPTOR,proto_dot_assets__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,github_dot_com_dot_mwitkow_dot_go__proto__validators_dot_validator__pb2.DESCRIPTOR,])




_PROPAGATECHAINEVENTREQUEST = _descriptor.Descriptor(
  name='PropagateChainEventRequest',
  full_name='api.PropagateChainEventRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='evt', full_name='api.PropagateChainEventRequest.evt', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=226,
  serialized_end=285,
)


_PROPAGATECHAINEVENTRESPONSE = _descriptor.Descriptor(
  name='PropagateChainEventResponse',
  full_name='api.PropagateChainEventResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='api.PropagateChainEventResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=287,
  serialized_end=333,
)


_SUBMITTRANSACTIONREQUEST = _descriptor.Descriptor(
  name='SubmitTransactionRequest',
  full_name='api.SubmitTransactionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tx', full_name='api.SubmitTransactionRequest.tx', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=335,
  serialized_end=393,
)


_SUBMITTRANSACTIONRESPONSE = _descriptor.Descriptor(
  name='SubmitTransactionResponse',
  full_name='api.SubmitTransactionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='api.SubmitTransactionResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=395,
  serialized_end=439,
)


_WITHDRAWREQUEST = _descriptor.Descriptor(
  name='WithdrawRequest',
  full_name='api.WithdrawRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='withdraw', full_name='api.WithdrawRequest.withdraw', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=441,
  serialized_end=492,
)


_WITHDRAWRESPONSE = _descriptor.Descriptor(
  name='WithdrawResponse',
  full_name='api.WithdrawResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='api.WithdrawResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=494,
  serialized_end=529,
)


_NOTIFYTRADERACCOUNTREQUEST = _descriptor.Descriptor(
  name='NotifyTraderAccountRequest',
  full_name='api.NotifyTraderAccountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='notif', full_name='api.NotifyTraderAccountRequest.notif', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=531,
  serialized_end=601,
)


_NOTIFYTRADERACCOUNTRESPONSE = _descriptor.Descriptor(
  name='NotifyTraderAccountResponse',
  full_name='api.NotifyTraderAccountResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='submitted', full_name='api.NotifyTraderAccountResponse.submitted', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=603,
  serialized_end=651,
)


_PREPARESUBMITORDERRESPONSE = _descriptor.Descriptor(
  name='PrepareSubmitOrderResponse',
  full_name='api.PrepareSubmitOrderResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blob', full_name='api.PrepareSubmitOrderResponse.blob', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='submitID', full_name='api.PrepareSubmitOrderResponse.submitID', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=653,
  serialized_end=713,
)


_PREPARECANCELORDERRESPONSE = _descriptor.Descriptor(
  name='PrepareCancelOrderResponse',
  full_name='api.PrepareCancelOrderResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blob', full_name='api.PrepareCancelOrderResponse.blob', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=715,
  serialized_end=757,
)


_PREPAREAMENDORDERRESPONSE = _descriptor.Descriptor(
  name='PrepareAmendOrderResponse',
  full_name='api.PrepareAmendOrderResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blob', full_name='api.PrepareAmendOrderResponse.blob', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=759,
  serialized_end=800,
)


_SUBMITORDERREQUEST = _descriptor.Descriptor(
  name='SubmitOrderRequest',
  full_name='api.SubmitOrderRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='submission', full_name='api.SubmitOrderRequest.submission', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=802,
  serialized_end=865,
)


_CANCELORDERREQUEST = _descriptor.Descriptor(
  name='CancelOrderRequest',
  full_name='api.CancelOrderRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cancellation', full_name='api.CancelOrderRequest.cancellation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=867,
  serialized_end=934,
)


_AMENDORDERREQUEST = _descriptor.Descriptor(
  name='AmendOrderRequest',
  full_name='api.AmendOrderRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='amendment', full_name='api.AmendOrderRequest.amendment', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=936,
  serialized_end=996,
)


_ASSETSREQUEST = _descriptor.Descriptor(
  name='AssetsRequest',
  full_name='api.AssetsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=998,
  serialized_end=1013,
)


_ASSETSRESPONSE = _descriptor.Descriptor(
  name='AssetsResponse',
  full_name='api.AssetsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='assets', full_name='api.AssetsResponse.assets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1015,
  serialized_end=1060,
)


_ASSETBYIDREQUEST = _descriptor.Descriptor(
  name='AssetByIDRequest',
  full_name='api.AssetByIDRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ID', full_name='api.AssetByIDRequest.ID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1062,
  serialized_end=1092,
)


_ASSETBYIDRESPONSE = _descriptor.Descriptor(
  name='AssetByIDResponse',
  full_name='api.AssetByIDResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='asset', full_name='api.AssetByIDResponse.asset', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1094,
  serialized_end=1141,
)


_GETNODESIGNATURESAGGREGATEREQUEST = _descriptor.Descriptor(
  name='GetNodeSignaturesAggregateRequest',
  full_name='api.GetNodeSignaturesAggregateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ID', full_name='api.GetNodeSignaturesAggregateRequest.ID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1143,
  serialized_end=1190,
)


_GETNODESIGNATURESAGGREGATERESPONSE = _descriptor.Descriptor(
  name='GetNodeSignaturesAggregateResponse',
  full_name='api.GetNodeSignaturesAggregateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='signatures', full_name='api.GetNodeSignaturesAggregateResponse.signatures', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1192,
  serialized_end=1269,
)


_OPTIONALPROPOSALSTATE = _descriptor.Descriptor(
  name='OptionalProposalState',
  full_name='api.OptionalProposalState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='api.OptionalProposalState.value', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1271,
  serialized_end=1331,
)


_GETPROPOSALSREQUEST = _descriptor.Descriptor(
  name='GetProposalsRequest',
  full_name='api.GetProposalsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='selectInState', full_name='api.GetProposalsRequest.selectInState', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1333,
  serialized_end=1405,
)


_GETPROPOSALSRESPONSE = _descriptor.Descriptor(
  name='GetProposalsResponse',
  full_name='api.GetProposalsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='api.GetProposalsResponse.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1407,
  serialized_end=1465,
)


_GETPROPOSALSBYPARTYREQUEST = _descriptor.Descriptor(
  name='GetProposalsByPartyRequest',
  full_name='api.GetProposalsByPartyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='partyID', full_name='api.GetProposalsByPartyRequest.partyID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='selectInState', full_name='api.GetProposalsByPartyRequest.selectInState', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1467,
  serialized_end=1571,
)


_GETPROPOSALSBYPARTYRESPONSE = _descriptor.Descriptor(
  name='GetProposalsByPartyResponse',
  full_name='api.GetProposalsByPartyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='api.GetProposalsByPartyResponse.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1573,
  serialized_end=1638,
)


_GETVOTESBYPARTYREQUEST = _descriptor.Descriptor(
  name='GetVotesByPartyRequest',
  full_name='api.GetVotesByPartyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='partyID', full_name='api.GetVotesByPartyRequest.partyID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1640,
  serialized_end=1689,
)


_GETVOTESBYPARTYRESPONSE = _descriptor.Descriptor(
  name='GetVotesByPartyResponse',
  full_name='api.GetVotesByPartyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='votes', full_name='api.GetVotesByPartyResponse.votes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1691,
  serialized_end=1743,
)


_GETNEWMARKETPROPOSALSREQUEST = _descriptor.Descriptor(
  name='GetNewMarketProposalsRequest',
  full_name='api.GetNewMarketProposalsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='selectInState', full_name='api.GetNewMarketProposalsRequest.selectInState', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1745,
  serialized_end=1826,
)


_GETNEWMARKETPROPOSALSRESPONSE = _descriptor.Descriptor(
  name='GetNewMarketProposalsResponse',
  full_name='api.GetNewMarketProposalsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='api.GetNewMarketProposalsResponse.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1828,
  serialized_end=1895,
)


_GETUPDATEMARKETPROPOSALSREQUEST = _descriptor.Descriptor(
  name='GetUpdateMarketProposalsRequest',
  full_name='api.GetUpdateMarketProposalsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='marketID', full_name='api.GetUpdateMarketProposalsRequest.marketID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='selectInState', full_name='api.GetUpdateMarketProposalsRequest.selectInState', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1897,
  serialized_end=2007,
)


_GETUPDATEMARKETPROPOSALSRESPONSE = _descriptor.Descriptor(
  name='GetUpdateMarketProposalsResponse',
  full_name='api.GetUpdateMarketProposalsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='api.GetUpdateMarketProposalsResponse.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2009,
  serialized_end=2079,
)


_GETNETWORKPARAMETERSPROPOSALSREQUEST = _descriptor.Descriptor(
  name='GetNetworkParametersProposalsRequest',
  full_name='api.GetNetworkParametersProposalsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='selectInState', full_name='api.GetNetworkParametersProposalsRequest.selectInState', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2081,
  serialized_end=2170,
)


_GETNETWORKPARAMETERSPROPOSALSRESPONSE = _descriptor.Descriptor(
  name='GetNetworkParametersProposalsResponse',
  full_name='api.GetNetworkParametersProposalsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='api.GetNetworkParametersProposalsResponse.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2172,
  serialized_end=2247,
)


_GETNEWASSETPROPOSALSREQUEST = _descriptor.Descriptor(
  name='GetNewAssetProposalsRequest',
  full_name='api.GetNewAssetProposalsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='selectInState', full_name='api.GetNewAssetProposalsRequest.selectInState', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2249,
  serialized_end=2329,
)


_GETNEWASSETPROPOSALSRESPONSE = _descriptor.Descriptor(
  name='GetNewAssetProposalsResponse',
  full_name='api.GetNewAssetProposalsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='api.GetNewAssetProposalsResponse.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2331,
  serialized_end=2397,
)


_GETPROPOSALBYIDREQUEST = _descriptor.Descriptor(
  name='GetProposalByIDRequest',
  full_name='api.GetProposalByIDRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='proposalID', full_name='api.GetProposalByIDRequest.proposalID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2399,
  serialized_end=2451,
)


_GETPROPOSALBYIDRESPONSE = _descriptor.Descriptor(
  name='GetProposalByIDResponse',
  full_name='api.GetProposalByIDResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='api.GetProposalByIDResponse.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2453,
  serialized_end=2514,
)


_GETPROPOSALBYREFERENCEREQUEST = _descriptor.Descriptor(
  name='GetProposalByReferenceRequest',
  full_name='api.GetProposalByReferenceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='Reference', full_name='api.GetProposalByReferenceRequest.Reference', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2516,
  serialized_end=2574,
)


_GETPROPOSALBYREFERENCERESPONSE = _descriptor.Descriptor(
  name='GetProposalByReferenceResponse',
  full_name='api.GetProposalByReferenceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='api.GetProposalByReferenceResponse.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2576,
  serialized_end=2644,
)


_OBSERVEPARTYPROPOSALSREQUEST = _descriptor.Descriptor(
  name='ObservePartyProposalsRequest',
  full_name='api.ObservePartyProposalsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='partyID', full_name='api.ObservePartyProposalsRequest.partyID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2646,
  serialized_end=2701,
)


_OBSERVEPROPOSALVOTESREQUEST = _descriptor.Descriptor(
  name='ObserveProposalVotesRequest',
  full_name='api.ObserveProposalVotesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='proposalID', full_name='api.ObserveProposalVotesRequest.proposalID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2703,
  serialized_end=2760,
)


_OBSERVEPARTYVOTESREQUEST = _descriptor.Descriptor(
  name='ObservePartyVotesRequest',
  full_name='api.ObservePartyVotesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='partyID', full_name='api.ObservePartyVotesRequest.partyID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2762,
  serialized_end=2813,
)


_MARGINLEVELSSUBSCRIBEREQUEST = _descriptor.Descriptor(
  name='MarginLevelsSubscribeRequest',
  full_name='api.MarginLevelsSubscribeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='partyID', full_name='api.MarginLevelsSubscribeRequest.partyID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='marketID', full_name='api.MarginLevelsSubscribeRequest.marketID', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2815,
  serialized_end=2888,
)


_MARGINLEVELSREQUEST = _descriptor.Descriptor(
  name='MarginLevelsRequest',
  full_name='api.MarginLevelsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='partyID', full_name='api.MarginLevelsRequest.partyID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='marketID', full_name='api.MarginLevelsRequest.marketID', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2890,
  serialized_end=2954,
)


_MARGINLEVELSRESPONSE = _descriptor.Descriptor(
  name='MarginLevelsResponse',
  full_name='api.MarginLevelsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='marginLevels', full_name='api.MarginLevelsResponse.marginLevels', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2956,
  serialized_end=3020,
)


_MARKETSDATASUBSCRIBEREQUEST = _descriptor.Descriptor(
  name='MarketsDataSubscribeRequest',
  full_name='api.MarketsDataSubscribeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='marketID', full_name='api.MarketsDataSubscribeRequest.marketID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3022,
  serialized_end=3069,
)


_MARKETDATABYIDREQUEST = _descriptor.Descriptor(
  name='MarketDataByIDRequest',
  full_name='api.MarketDataByIDRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='marketID', full_name='api.MarketDataByIDRequest.marketID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3071,
  serialized_end=3120,
)


_MARKETDATABYIDRESPONSE = _descriptor.Descriptor(
  name='MarketDataByIDResponse',
  full_name='api.MarketDataByIDResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='marketData', full_name='api.MarketDataByIDResponse.marketData', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3122,
  serialized_end=3184,
)


_MARKETSDATARESPONSE = _descriptor.Descriptor(
  name='MarketsDataResponse',
  full_name='api.MarketsDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='marketsData', full_name='api.MarketsDataResponse.marketsData', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3186,
  serialized_end=3246,
)


_LASTTRADEREQUEST = _descriptor.Descriptor(
  name='LastTradeRequest',
  full_name='api.LastTradeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='marketID', full_name='api.LastTradeRequest.marketID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3248,
  serialized_end=3292,
)


_LASTTRADERESPONSE = _descriptor.Descriptor(
  name='LastTradeResponse',
  full_name='api.LastTradeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='trade', full_name='api.LastTradeResponse.trade', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3294,
  serialized_end=3341,
)


_MARKETBYIDREQUEST = _descriptor.Descriptor(
  name='MarketByIDRequest',
  full_name='api.MarketByIDRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='marketID', full_name='api.MarketByIDRequest.marketID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3343,
  serialized_end=3388,
)


_MARKETBYIDRESPONSE = _descriptor.Descriptor(
  name='MarketByIDResponse',
  full_name='api.MarketByIDResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='market', full_name='api.MarketByIDResponse.market', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3390,
  serialized_end=3440,
)


_PARTYBYIDREQUEST = _descriptor.Descriptor(
  name='PartyByIDRequest',
  full_name='api.PartyByIDRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='partyID', full_name='api.PartyByIDRequest.partyID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3442,
  serialized_end=3485,
)


_PARTYBYIDRESPONSE = _descriptor.Descriptor(
  name='PartyByIDResponse',
  full_name='api.PartyByIDResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='party', full_name='api.PartyByIDResponse.party', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3487,
  serialized_end=3534,
)


_PARTIESRESPONSE = _descriptor.Descriptor(
  name='PartiesResponse',
  full_name='api.PartiesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parties', full_name='api.PartiesResponse.parties', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3536,
  serialized_end=3583,
)


_TRADESBYPARTYREQUEST = _descriptor.Descriptor(
  name='TradesByPartyRequest',
  full_name='api.TradesByPartyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='partyID', full_name='api.TradesByPartyRequest.partyID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='marketID', full_name='api.TradesByPartyRequest.marketID', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='api.TradesByPartyRequest.pagination', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3585,
  serialized_end=3679,
)


_TRADESBYPARTYRESPONSE = _descriptor.Descriptor(
  name='TradesByPartyResponse',
  full_name='api.TradesByPartyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='trades', full_name='api.TradesByPartyResponse.trades', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3681,
  serialized_end=3733,
)


_TRADESBYORDERREQUEST = _descriptor.Descriptor(
  name='TradesByOrderRequest',
  full_name='api.TradesByOrderRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='orderID', full_name='api.TradesByOrderRequest.orderID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3735,
  serialized_end=3774,
)


_TRADESBYORDERRESPONSE = _descriptor.Descriptor(
  name='TradesByOrderResponse',
  full_name='api.TradesByOrderResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='trades', full_name='api.TradesByOrderResponse.trades', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3776,
  serialized_end=3828,
)


_ACCOUNTSSUBSCRIBEREQUEST = _descriptor.Descriptor(
  name='AccountsSubscribeRequest',
  full_name='api.AccountsSubscribeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='marketID', full_name='api.AccountsSubscribeRequest.marketID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partyID', full_name='api.AccountsSubscribeRequest.partyID', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='asset', full_name='api.AccountsSubscribeRequest.asset', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='api.AccountsSubscribeRequest.type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3830,
  serialized_end=3939,
)


_ORDERSSUBSCRIBEREQUEST = _descriptor.Descriptor(
  name='OrdersSubscribeRequest',
  full_name='api.OrdersSubscribeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='marketID', full_name='api.OrdersSubscribeRequest.marketID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partyID', full_name='api.OrdersSubscribeRequest.partyID', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3941,
  serialized_end=4000,
)


_TRADESSUBSCRIBEREQUEST = _descriptor.Descriptor(
  name='TradesSubscribeRequest',
  full_name='api.TradesSubscribeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='marketID', full_name='api.TradesSubscribeRequest.marketID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partyID', full_name='api.TradesSubscribeRequest.partyID', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4002,
  serialized_end=4061,
)


_CANDLESSUBSCRIBEREQUEST = _descriptor.Descriptor(
  name='CandlesSubscribeRequest',
  full_name='api.CandlesSubscribeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='marketID', full_name='api.CandlesSubscribeRequest.marketID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interval', full_name='api.CandlesSubscribeRequest.interval', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4063,
  serialized_end=4148,
)


_MARKETDEPTHSUBSCRIBEREQUEST = _descriptor.Descriptor(
  name='MarketDepthSubscribeRequest',
  full_name='api.MarketDepthSubscribeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='marketID', full_name='api.MarketDepthSubscribeRequest.marketID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4150,
  serialized_end=4205,
)


_POSITIONSSUBSCRIBEREQUEST = _descriptor.Descriptor(
  name='PositionsSubscribeRequest',
  full_name='api.PositionsSubscribeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='partyID', full_name='api.PositionsSubscribeRequest.partyID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4207,
  serialized_end=4251,
)


_ORDERSBYMARKETREQUEST = _descriptor.Descriptor(
  name='OrdersByMarketRequest',
  full_name='api.OrdersByMarketRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='marketID', full_name='api.OrdersByMarketRequest.marketID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='api.OrdersByMarketRequest.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4253,
  serialized_end=4339,
)


_ORDERSBYMARKETRESPONSE = _descriptor.Descriptor(
  name='OrdersByMarketResponse',
  full_name='api.OrdersByMarketResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='orders', full_name='api.OrdersByMarketResponse.orders', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4341,
  serialized_end=4394,
)


_ORDERSBYPARTYREQUEST = _descriptor.Descriptor(
  name='OrdersByPartyRequest',
  full_name='api.OrdersByPartyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='partyID', full_name='api.OrdersByPartyRequest.partyID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='api.OrdersByPartyRequest.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4396,
  serialized_end=4480,
)


_ORDERSBYPARTYRESPONSE = _descriptor.Descriptor(
  name='OrdersByPartyResponse',
  full_name='api.OrdersByPartyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='orders', full_name='api.OrdersByPartyResponse.orders', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4482,
  serialized_end=4534,
)


_ORDERBYMARKETANDIDREQUEST = _descriptor.Descriptor(
  name='OrderByMarketAndIdRequest',
  full_name='api.OrderByMarketAndIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='marketID', full_name='api.OrderByMarketAndIdRequest.marketID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='orderID', full_name='api.OrderByMarketAndIdRequest.orderID', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4536,
  serialized_end=4614,
)


_ORDERBYMARKETANDIDRESPONSE = _descriptor.Descriptor(
  name='OrderByMarketAndIdResponse',
  full_name='api.OrderByMarketAndIdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='order', full_name='api.OrderByMarketAndIdResponse.order', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4616,
  serialized_end=4672,
)


_ORDERBYREFERENCEREQUEST = _descriptor.Descriptor(
  name='OrderByReferenceRequest',
  full_name='api.OrderByReferenceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='reference', full_name='api.OrderByReferenceRequest.reference', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4674,
  serialized_end=4726,
)


_ORDERBYREFERENCERESPONSE = _descriptor.Descriptor(
  name='OrderByReferenceResponse',
  full_name='api.OrderByReferenceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='order', full_name='api.OrderByReferenceResponse.order', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4728,
  serialized_end=4782,
)


_MARKETSRESPONSE = _descriptor.Descriptor(
  name='MarketsResponse',
  full_name='api.MarketsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='markets', full_name='api.MarketsResponse.markets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4784,
  serialized_end=4832,
)


_CANDLESREQUEST = _descriptor.Descriptor(
  name='CandlesRequest',
  full_name='api.CandlesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='marketID', full_name='api.CandlesRequest.marketID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sinceTimestamp', full_name='api.CandlesRequest.sinceTimestamp', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002\020\000', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interval', full_name='api.CandlesRequest.interval', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4834,
  serialized_end=4942,
)


_CANDLESRESPONSE = _descriptor.Descriptor(
  name='CandlesResponse',
  full_name='api.CandlesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='candles', full_name='api.CandlesResponse.candles', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4944,
  serialized_end=4992,
)


_MARKETDEPTHREQUEST = _descriptor.Descriptor(
  name='MarketDepthRequest',
  full_name='api.MarketDepthRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='marketID', full_name='api.MarketDepthRequest.marketID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxDepth', full_name='api.MarketDepthRequest.maxDepth', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4994,
  serialized_end=5058,
)


_MARKETDEPTHRESPONSE = _descriptor.Descriptor(
  name='MarketDepthResponse',
  full_name='api.MarketDepthResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='marketID', full_name='api.MarketDepthResponse.marketID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='buy', full_name='api.MarketDepthResponse.buy', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sell', full_name='api.MarketDepthResponse.sell', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lastTrade', full_name='api.MarketDepthResponse.lastTrade', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5061,
  serialized_end=5195,
)


_TRADESBYMARKETREQUEST = _descriptor.Descriptor(
  name='TradesByMarketRequest',
  full_name='api.TradesByMarketRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='marketID', full_name='api.TradesByMarketRequest.marketID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='api.TradesByMarketRequest.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5197,
  serialized_end=5283,
)


_TRADESBYMARKETRESPONSE = _descriptor.Descriptor(
  name='TradesByMarketResponse',
  full_name='api.TradesByMarketResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='trades', full_name='api.TradesByMarketResponse.trades', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5285,
  serialized_end=5338,
)


_POSITIONSBYPARTYREQUEST = _descriptor.Descriptor(
  name='PositionsByPartyRequest',
  full_name='api.PositionsByPartyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='partyID', full_name='api.PositionsByPartyRequest.partyID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='marketID', full_name='api.PositionsByPartyRequest.marketID', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5340,
  serialized_end=5408,
)


_POSITIONSBYPARTYRESPONSE = _descriptor.Descriptor(
  name='PositionsByPartyResponse',
  full_name='api.PositionsByPartyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='positions', full_name='api.PositionsByPartyResponse.positions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5410,
  serialized_end=5471,
)


_VEGATIMERESPONSE = _descriptor.Descriptor(
  name='VegaTimeResponse',
  full_name='api.VegaTimeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='api.VegaTimeResponse.timestamp', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5473,
  serialized_end=5510,
)


_PAGINATION = _descriptor.Descriptor(
  name='Pagination',
  full_name='api.Pagination',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='skip', full_name='api.Pagination.skip', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='api.Pagination.limit', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='descending', full_name='api.Pagination.descending', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5512,
  serialized_end=5573,
)


_ORDERSSTREAM = _descriptor.Descriptor(
  name='OrdersStream',
  full_name='api.OrdersStream',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='orders', full_name='api.OrdersStream.orders', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5575,
  serialized_end=5618,
)


_TRADESSTREAM = _descriptor.Descriptor(
  name='TradesStream',
  full_name='api.TradesStream',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='trades', full_name='api.TradesStream.trades', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5620,
  serialized_end=5663,
)


_PARTYACCOUNTSREQUEST = _descriptor.Descriptor(
  name='PartyAccountsRequest',
  full_name='api.PartyAccountsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='partyID', full_name='api.PartyAccountsRequest.partyID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='marketID', full_name='api.PartyAccountsRequest.marketID', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='api.PartyAccountsRequest.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='asset', full_name='api.PartyAccountsRequest.asset', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5665,
  serialized_end=5770,
)


_PARTYACCOUNTSRESPONSE = _descriptor.Descriptor(
  name='PartyAccountsResponse',
  full_name='api.PartyAccountsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='accounts', full_name='api.PartyAccountsResponse.accounts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5772,
  serialized_end=5828,
)


_MARKETACCOUNTSREQUEST = _descriptor.Descriptor(
  name='MarketAccountsRequest',
  full_name='api.MarketAccountsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='marketID', full_name='api.MarketAccountsRequest.marketID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='asset', full_name='api.MarketAccountsRequest.asset', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5830,
  serialized_end=5886,
)


_MARKETACCOUNTSRESPONSE = _descriptor.Descriptor(
  name='MarketAccountsResponse',
  full_name='api.MarketAccountsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='accounts', full_name='api.MarketAccountsResponse.accounts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5888,
  serialized_end=5945,
)


_PREPAREPROPOSALREQUEST = _descriptor.Descriptor(
  name='PrepareProposalRequest',
  full_name='api.PrepareProposalRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='partyID', full_name='api.PrepareProposalRequest.partyID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reference', full_name='api.PrepareProposalRequest.reference', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proposal', full_name='api.PrepareProposalRequest.proposal', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002 \001', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5947,
  serialized_end=6062,
)


_PREPAREPROPOSALRESPONSE = _descriptor.Descriptor(
  name='PrepareProposalResponse',
  full_name='api.PrepareProposalResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blob', full_name='api.PrepareProposalResponse.blob', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pendingProposal', full_name='api.PrepareProposalResponse.pendingProposal', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6064,
  serialized_end=6144,
)


_PREPAREVOTEREQUEST = _descriptor.Descriptor(
  name='PrepareVoteRequest',
  full_name='api.PrepareVoteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vote', full_name='api.PrepareVoteRequest.vote', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002 \001', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6146,
  serialized_end=6200,
)


_PREPAREVOTERESPONSE = _descriptor.Descriptor(
  name='PrepareVoteResponse',
  full_name='api.PrepareVoteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blob', full_name='api.PrepareVoteResponse.blob', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vote', full_name='api.PrepareVoteResponse.vote', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6202,
  serialized_end=6263,
)


_ORDERBYIDREQUEST = _descriptor.Descriptor(
  name='OrderByIDRequest',
  full_name='api.OrderByIDRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='orderID', full_name='api.OrderByIDRequest.orderID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002 \001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='api.OrderByIDRequest.version', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6265,
  serialized_end=6325,
)


_ORDERBYREFERENCEIDREQUEST = _descriptor.Descriptor(
  name='OrderByReferenceIDRequest',
  full_name='api.OrderByReferenceIDRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='referenceID', full_name='api.OrderByReferenceIDRequest.referenceID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002 \001', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6327,
  serialized_end=6383,
)


_ORDERVERSIONSBYIDREQUEST = _descriptor.Descriptor(
  name='OrderVersionsByIDRequest',
  full_name='api.OrderVersionsByIDRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='orderID', full_name='api.OrderVersionsByIDRequest.orderID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002 \001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='api.OrderVersionsByIDRequest.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6385,
  serialized_end=6473,
)


_ORDERVERSIONSRESPONSE = _descriptor.Descriptor(
  name='OrderVersionsResponse',
  full_name='api.OrderVersionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='orders', full_name='api.OrderVersionsResponse.orders', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6475,
  serialized_end=6527,
)

_PROPAGATECHAINEVENTREQUEST.fields_by_name['evt'].message_type = proto_dot_chain__events__pb2._CHAINEVENT
_SUBMITTRANSACTIONREQUEST.fields_by_name['tx'].message_type = proto_dot_vega__pb2._SIGNEDBUNDLE
_WITHDRAWREQUEST.fields_by_name['withdraw'].message_type = proto_dot_vega__pb2._WITHDRAW
_NOTIFYTRADERACCOUNTREQUEST.fields_by_name['notif'].message_type = proto_dot_vega__pb2._NOTIFYTRADERACCOUNT
_SUBMITORDERREQUEST.fields_by_name['submission'].message_type = proto_dot_vega__pb2._ORDERSUBMISSION
_CANCELORDERREQUEST.fields_by_name['cancellation'].message_type = proto_dot_vega__pb2._ORDERCANCELLATION
_AMENDORDERREQUEST.fields_by_name['amendment'].message_type = proto_dot_vega__pb2._ORDERAMENDMENT
_ASSETSRESPONSE.fields_by_name['assets'].message_type = proto_dot_assets__pb2._ASSET
_ASSETBYIDRESPONSE.fields_by_name['asset'].message_type = proto_dot_assets__pb2._ASSET
_GETNODESIGNATURESAGGREGATERESPONSE.fields_by_name['signatures'].message_type = proto_dot_vega__pb2._NODESIGNATURE
_OPTIONALPROPOSALSTATE.fields_by_name['value'].enum_type = proto_dot_governance__pb2._PROPOSAL_STATE
_GETPROPOSALSREQUEST.fields_by_name['selectInState'].message_type = _OPTIONALPROPOSALSTATE
_GETPROPOSALSRESPONSE.fields_by_name['data'].message_type = proto_dot_governance__pb2._GOVERNANCEDATA
_GETPROPOSALSBYPARTYREQUEST.fields_by_name['selectInState'].message_type = _OPTIONALPROPOSALSTATE
_GETPROPOSALSBYPARTYRESPONSE.fields_by_name['data'].message_type = proto_dot_governance__pb2._GOVERNANCEDATA
_GETVOTESBYPARTYRESPONSE.fields_by_name['votes'].message_type = proto_dot_governance__pb2._VOTE
_GETNEWMARKETPROPOSALSREQUEST.fields_by_name['selectInState'].message_type = _OPTIONALPROPOSALSTATE
_GETNEWMARKETPROPOSALSRESPONSE.fields_by_name['data'].message_type = proto_dot_governance__pb2._GOVERNANCEDATA
_GETUPDATEMARKETPROPOSALSREQUEST.fields_by_name['selectInState'].message_type = _OPTIONALPROPOSALSTATE
_GETUPDATEMARKETPROPOSALSRESPONSE.fields_by_name['data'].message_type = proto_dot_governance__pb2._GOVERNANCEDATA
_GETNETWORKPARAMETERSPROPOSALSREQUEST.fields_by_name['selectInState'].message_type = _OPTIONALPROPOSALSTATE
_GETNETWORKPARAMETERSPROPOSALSRESPONSE.fields_by_name['data'].message_type = proto_dot_governance__pb2._GOVERNANCEDATA
_GETNEWASSETPROPOSALSREQUEST.fields_by_name['selectInState'].message_type = _OPTIONALPROPOSALSTATE
_GETNEWASSETPROPOSALSRESPONSE.fields_by_name['data'].message_type = proto_dot_governance__pb2._GOVERNANCEDATA
_GETPROPOSALBYIDRESPONSE.fields_by_name['data'].message_type = proto_dot_governance__pb2._GOVERNANCEDATA
_GETPROPOSALBYREFERENCERESPONSE.fields_by_name['data'].message_type = proto_dot_governance__pb2._GOVERNANCEDATA
_MARGINLEVELSRESPONSE.fields_by_name['marginLevels'].message_type = proto_dot_vega__pb2._MARGINLEVELS
_MARKETDATABYIDRESPONSE.fields_by_name['marketData'].message_type = proto_dot_vega__pb2._MARKETDATA
_MARKETSDATARESPONSE.fields_by_name['marketsData'].message_type = proto_dot_vega__pb2._MARKETDATA
_LASTTRADERESPONSE.fields_by_name['trade'].message_type = proto_dot_vega__pb2._TRADE
_MARKETBYIDRESPONSE.fields_by_name['market'].message_type = proto_dot_markets__pb2._MARKET
_PARTYBYIDRESPONSE.fields_by_name['party'].message_type = proto_dot_vega__pb2._PARTY
_PARTIESRESPONSE.fields_by_name['parties'].message_type = proto_dot_vega__pb2._PARTY
_TRADESBYPARTYREQUEST.fields_by_name['pagination'].message_type = _PAGINATION
_TRADESBYPARTYRESPONSE.fields_by_name['trades'].message_type = proto_dot_vega__pb2._TRADE
_TRADESBYORDERRESPONSE.fields_by_name['trades'].message_type = proto_dot_vega__pb2._TRADE
_ACCOUNTSSUBSCRIBEREQUEST.fields_by_name['type'].enum_type = proto_dot_vega__pb2._ACCOUNTTYPE
_CANDLESSUBSCRIBEREQUEST.fields_by_name['interval'].enum_type = proto_dot_vega__pb2._INTERVAL
_ORDERSBYMARKETREQUEST.fields_by_name['pagination'].message_type = _PAGINATION
_ORDERSBYMARKETRESPONSE.fields_by_name['orders'].message_type = proto_dot_vega__pb2._ORDER
_ORDERSBYPARTYREQUEST.fields_by_name['pagination'].message_type = _PAGINATION
_ORDERSBYPARTYRESPONSE.fields_by_name['orders'].message_type = proto_dot_vega__pb2._ORDER
_ORDERBYMARKETANDIDRESPONSE.fields_by_name['order'].message_type = proto_dot_vega__pb2._ORDER
_ORDERBYREFERENCERESPONSE.fields_by_name['order'].message_type = proto_dot_vega__pb2._ORDER
_MARKETSRESPONSE.fields_by_name['markets'].message_type = proto_dot_markets__pb2._MARKET
_CANDLESREQUEST.fields_by_name['interval'].enum_type = proto_dot_vega__pb2._INTERVAL
_CANDLESRESPONSE.fields_by_name['candles'].message_type = proto_dot_vega__pb2._CANDLE
_MARKETDEPTHRESPONSE.fields_by_name['buy'].message_type = proto_dot_vega__pb2._PRICELEVEL
_MARKETDEPTHRESPONSE.fields_by_name['sell'].message_type = proto_dot_vega__pb2._PRICELEVEL
_MARKETDEPTHRESPONSE.fields_by_name['lastTrade'].message_type = proto_dot_vega__pb2._TRADE
_TRADESBYMARKETREQUEST.fields_by_name['pagination'].message_type = _PAGINATION
_TRADESBYMARKETRESPONSE.fields_by_name['trades'].message_type = proto_dot_vega__pb2._TRADE
_POSITIONSBYPARTYRESPONSE.fields_by_name['positions'].message_type = proto_dot_vega__pb2._POSITION
_ORDERSSTREAM.fields_by_name['orders'].message_type = proto_dot_vega__pb2._ORDER
_TRADESSTREAM.fields_by_name['trades'].message_type = proto_dot_vega__pb2._TRADE
_PARTYACCOUNTSREQUEST.fields_by_name['type'].enum_type = proto_dot_vega__pb2._ACCOUNTTYPE
_PARTYACCOUNTSRESPONSE.fields_by_name['accounts'].message_type = proto_dot_vega__pb2._ACCOUNT
_MARKETACCOUNTSRESPONSE.fields_by_name['accounts'].message_type = proto_dot_vega__pb2._ACCOUNT
_PREPAREPROPOSALREQUEST.fields_by_name['proposal'].message_type = proto_dot_governance__pb2._PROPOSALTERMS
_PREPAREPROPOSALRESPONSE.fields_by_name['pendingProposal'].message_type = proto_dot_governance__pb2._PROPOSAL
_PREPAREVOTEREQUEST.fields_by_name['vote'].message_type = proto_dot_governance__pb2._VOTE
_PREPAREVOTERESPONSE.fields_by_name['vote'].message_type = proto_dot_governance__pb2._VOTE
_ORDERVERSIONSBYIDREQUEST.fields_by_name['pagination'].message_type = _PAGINATION
_ORDERVERSIONSRESPONSE.fields_by_name['orders'].message_type = proto_dot_vega__pb2._ORDER
DESCRIPTOR.message_types_by_name['PropagateChainEventRequest'] = _PROPAGATECHAINEVENTREQUEST
DESCRIPTOR.message_types_by_name['PropagateChainEventResponse'] = _PROPAGATECHAINEVENTRESPONSE
DESCRIPTOR.message_types_by_name['SubmitTransactionRequest'] = _SUBMITTRANSACTIONREQUEST
DESCRIPTOR.message_types_by_name['SubmitTransactionResponse'] = _SUBMITTRANSACTIONRESPONSE
DESCRIPTOR.message_types_by_name['WithdrawRequest'] = _WITHDRAWREQUEST
DESCRIPTOR.message_types_by_name['WithdrawResponse'] = _WITHDRAWRESPONSE
DESCRIPTOR.message_types_by_name['NotifyTraderAccountRequest'] = _NOTIFYTRADERACCOUNTREQUEST
DESCRIPTOR.message_types_by_name['NotifyTraderAccountResponse'] = _NOTIFYTRADERACCOUNTRESPONSE
DESCRIPTOR.message_types_by_name['PrepareSubmitOrderResponse'] = _PREPARESUBMITORDERRESPONSE
DESCRIPTOR.message_types_by_name['PrepareCancelOrderResponse'] = _PREPARECANCELORDERRESPONSE
DESCRIPTOR.message_types_by_name['PrepareAmendOrderResponse'] = _PREPAREAMENDORDERRESPONSE
DESCRIPTOR.message_types_by_name['SubmitOrderRequest'] = _SUBMITORDERREQUEST
DESCRIPTOR.message_types_by_name['CancelOrderRequest'] = _CANCELORDERREQUEST
DESCRIPTOR.message_types_by_name['AmendOrderRequest'] = _AMENDORDERREQUEST
DESCRIPTOR.message_types_by_name['AssetsRequest'] = _ASSETSREQUEST
DESCRIPTOR.message_types_by_name['AssetsResponse'] = _ASSETSRESPONSE
DESCRIPTOR.message_types_by_name['AssetByIDRequest'] = _ASSETBYIDREQUEST
DESCRIPTOR.message_types_by_name['AssetByIDResponse'] = _ASSETBYIDRESPONSE
DESCRIPTOR.message_types_by_name['GetNodeSignaturesAggregateRequest'] = _GETNODESIGNATURESAGGREGATEREQUEST
DESCRIPTOR.message_types_by_name['GetNodeSignaturesAggregateResponse'] = _GETNODESIGNATURESAGGREGATERESPONSE
DESCRIPTOR.message_types_by_name['OptionalProposalState'] = _OPTIONALPROPOSALSTATE
DESCRIPTOR.message_types_by_name['GetProposalsRequest'] = _GETPROPOSALSREQUEST
DESCRIPTOR.message_types_by_name['GetProposalsResponse'] = _GETPROPOSALSRESPONSE
DESCRIPTOR.message_types_by_name['GetProposalsByPartyRequest'] = _GETPROPOSALSBYPARTYREQUEST
DESCRIPTOR.message_types_by_name['GetProposalsByPartyResponse'] = _GETPROPOSALSBYPARTYRESPONSE
DESCRIPTOR.message_types_by_name['GetVotesByPartyRequest'] = _GETVOTESBYPARTYREQUEST
DESCRIPTOR.message_types_by_name['GetVotesByPartyResponse'] = _GETVOTESBYPARTYRESPONSE
DESCRIPTOR.message_types_by_name['GetNewMarketProposalsRequest'] = _GETNEWMARKETPROPOSALSREQUEST
DESCRIPTOR.message_types_by_name['GetNewMarketProposalsResponse'] = _GETNEWMARKETPROPOSALSRESPONSE
DESCRIPTOR.message_types_by_name['GetUpdateMarketProposalsRequest'] = _GETUPDATEMARKETPROPOSALSREQUEST
DESCRIPTOR.message_types_by_name['GetUpdateMarketProposalsResponse'] = _GETUPDATEMARKETPROPOSALSRESPONSE
DESCRIPTOR.message_types_by_name['GetNetworkParametersProposalsRequest'] = _GETNETWORKPARAMETERSPROPOSALSREQUEST
DESCRIPTOR.message_types_by_name['GetNetworkParametersProposalsResponse'] = _GETNETWORKPARAMETERSPROPOSALSRESPONSE
DESCRIPTOR.message_types_by_name['GetNewAssetProposalsRequest'] = _GETNEWASSETPROPOSALSREQUEST
DESCRIPTOR.message_types_by_name['GetNewAssetProposalsResponse'] = _GETNEWASSETPROPOSALSRESPONSE
DESCRIPTOR.message_types_by_name['GetProposalByIDRequest'] = _GETPROPOSALBYIDREQUEST
DESCRIPTOR.message_types_by_name['GetProposalByIDResponse'] = _GETPROPOSALBYIDRESPONSE
DESCRIPTOR.message_types_by_name['GetProposalByReferenceRequest'] = _GETPROPOSALBYREFERENCEREQUEST
DESCRIPTOR.message_types_by_name['GetProposalByReferenceResponse'] = _GETPROPOSALBYREFERENCERESPONSE
DESCRIPTOR.message_types_by_name['ObservePartyProposalsRequest'] = _OBSERVEPARTYPROPOSALSREQUEST
DESCRIPTOR.message_types_by_name['ObserveProposalVotesRequest'] = _OBSERVEPROPOSALVOTESREQUEST
DESCRIPTOR.message_types_by_name['ObservePartyVotesRequest'] = _OBSERVEPARTYVOTESREQUEST
DESCRIPTOR.message_types_by_name['MarginLevelsSubscribeRequest'] = _MARGINLEVELSSUBSCRIBEREQUEST
DESCRIPTOR.message_types_by_name['MarginLevelsRequest'] = _MARGINLEVELSREQUEST
DESCRIPTOR.message_types_by_name['MarginLevelsResponse'] = _MARGINLEVELSRESPONSE
DESCRIPTOR.message_types_by_name['MarketsDataSubscribeRequest'] = _MARKETSDATASUBSCRIBEREQUEST
DESCRIPTOR.message_types_by_name['MarketDataByIDRequest'] = _MARKETDATABYIDREQUEST
DESCRIPTOR.message_types_by_name['MarketDataByIDResponse'] = _MARKETDATABYIDRESPONSE
DESCRIPTOR.message_types_by_name['MarketsDataResponse'] = _MARKETSDATARESPONSE
DESCRIPTOR.message_types_by_name['LastTradeRequest'] = _LASTTRADEREQUEST
DESCRIPTOR.message_types_by_name['LastTradeResponse'] = _LASTTRADERESPONSE
DESCRIPTOR.message_types_by_name['MarketByIDRequest'] = _MARKETBYIDREQUEST
DESCRIPTOR.message_types_by_name['MarketByIDResponse'] = _MARKETBYIDRESPONSE
DESCRIPTOR.message_types_by_name['PartyByIDRequest'] = _PARTYBYIDREQUEST
DESCRIPTOR.message_types_by_name['PartyByIDResponse'] = _PARTYBYIDRESPONSE
DESCRIPTOR.message_types_by_name['PartiesResponse'] = _PARTIESRESPONSE
DESCRIPTOR.message_types_by_name['TradesByPartyRequest'] = _TRADESBYPARTYREQUEST
DESCRIPTOR.message_types_by_name['TradesByPartyResponse'] = _TRADESBYPARTYRESPONSE
DESCRIPTOR.message_types_by_name['TradesByOrderRequest'] = _TRADESBYORDERREQUEST
DESCRIPTOR.message_types_by_name['TradesByOrderResponse'] = _TRADESBYORDERRESPONSE
DESCRIPTOR.message_types_by_name['AccountsSubscribeRequest'] = _ACCOUNTSSUBSCRIBEREQUEST
DESCRIPTOR.message_types_by_name['OrdersSubscribeRequest'] = _ORDERSSUBSCRIBEREQUEST
DESCRIPTOR.message_types_by_name['TradesSubscribeRequest'] = _TRADESSUBSCRIBEREQUEST
DESCRIPTOR.message_types_by_name['CandlesSubscribeRequest'] = _CANDLESSUBSCRIBEREQUEST
DESCRIPTOR.message_types_by_name['MarketDepthSubscribeRequest'] = _MARKETDEPTHSUBSCRIBEREQUEST
DESCRIPTOR.message_types_by_name['PositionsSubscribeRequest'] = _POSITIONSSUBSCRIBEREQUEST
DESCRIPTOR.message_types_by_name['OrdersByMarketRequest'] = _ORDERSBYMARKETREQUEST
DESCRIPTOR.message_types_by_name['OrdersByMarketResponse'] = _ORDERSBYMARKETRESPONSE
DESCRIPTOR.message_types_by_name['OrdersByPartyRequest'] = _ORDERSBYPARTYREQUEST
DESCRIPTOR.message_types_by_name['OrdersByPartyResponse'] = _ORDERSBYPARTYRESPONSE
DESCRIPTOR.message_types_by_name['OrderByMarketAndIdRequest'] = _ORDERBYMARKETANDIDREQUEST
DESCRIPTOR.message_types_by_name['OrderByMarketAndIdResponse'] = _ORDERBYMARKETANDIDRESPONSE
DESCRIPTOR.message_types_by_name['OrderByReferenceRequest'] = _ORDERBYREFERENCEREQUEST
DESCRIPTOR.message_types_by_name['OrderByReferenceResponse'] = _ORDERBYREFERENCERESPONSE
DESCRIPTOR.message_types_by_name['MarketsResponse'] = _MARKETSRESPONSE
DESCRIPTOR.message_types_by_name['CandlesRequest'] = _CANDLESREQUEST
DESCRIPTOR.message_types_by_name['CandlesResponse'] = _CANDLESRESPONSE
DESCRIPTOR.message_types_by_name['MarketDepthRequest'] = _MARKETDEPTHREQUEST
DESCRIPTOR.message_types_by_name['MarketDepthResponse'] = _MARKETDEPTHRESPONSE
DESCRIPTOR.message_types_by_name['TradesByMarketRequest'] = _TRADESBYMARKETREQUEST
DESCRIPTOR.message_types_by_name['TradesByMarketResponse'] = _TRADESBYMARKETRESPONSE
DESCRIPTOR.message_types_by_name['PositionsByPartyRequest'] = _POSITIONSBYPARTYREQUEST
DESCRIPTOR.message_types_by_name['PositionsByPartyResponse'] = _POSITIONSBYPARTYRESPONSE
DESCRIPTOR.message_types_by_name['VegaTimeResponse'] = _VEGATIMERESPONSE
DESCRIPTOR.message_types_by_name['Pagination'] = _PAGINATION
DESCRIPTOR.message_types_by_name['OrdersStream'] = _ORDERSSTREAM
DESCRIPTOR.message_types_by_name['TradesStream'] = _TRADESSTREAM
DESCRIPTOR.message_types_by_name['PartyAccountsRequest'] = _PARTYACCOUNTSREQUEST
DESCRIPTOR.message_types_by_name['PartyAccountsResponse'] = _PARTYACCOUNTSRESPONSE
DESCRIPTOR.message_types_by_name['MarketAccountsRequest'] = _MARKETACCOUNTSREQUEST
DESCRIPTOR.message_types_by_name['MarketAccountsResponse'] = _MARKETACCOUNTSRESPONSE
DESCRIPTOR.message_types_by_name['PrepareProposalRequest'] = _PREPAREPROPOSALREQUEST
DESCRIPTOR.message_types_by_name['PrepareProposalResponse'] = _PREPAREPROPOSALRESPONSE
DESCRIPTOR.message_types_by_name['PrepareVoteRequest'] = _PREPAREVOTEREQUEST
DESCRIPTOR.message_types_by_name['PrepareVoteResponse'] = _PREPAREVOTERESPONSE
DESCRIPTOR.message_types_by_name['OrderByIDRequest'] = _ORDERBYIDREQUEST
DESCRIPTOR.message_types_by_name['OrderByReferenceIDRequest'] = _ORDERBYREFERENCEIDREQUEST
DESCRIPTOR.message_types_by_name['OrderVersionsByIDRequest'] = _ORDERVERSIONSBYIDREQUEST
DESCRIPTOR.message_types_by_name['OrderVersionsResponse'] = _ORDERVERSIONSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PropagateChainEventRequest = _reflection.GeneratedProtocolMessageType('PropagateChainEventRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROPAGATECHAINEVENTREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.PropagateChainEventRequest)
  })
_sym_db.RegisterMessage(PropagateChainEventRequest)

PropagateChainEventResponse = _reflection.GeneratedProtocolMessageType('PropagateChainEventResponse', (_message.Message,), {
  'DESCRIPTOR' : _PROPAGATECHAINEVENTRESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.PropagateChainEventResponse)
  })
_sym_db.RegisterMessage(PropagateChainEventResponse)

SubmitTransactionRequest = _reflection.GeneratedProtocolMessageType('SubmitTransactionRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBMITTRANSACTIONREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.SubmitTransactionRequest)
  })
_sym_db.RegisterMessage(SubmitTransactionRequest)

SubmitTransactionResponse = _reflection.GeneratedProtocolMessageType('SubmitTransactionResponse', (_message.Message,), {
  'DESCRIPTOR' : _SUBMITTRANSACTIONRESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.SubmitTransactionResponse)
  })
_sym_db.RegisterMessage(SubmitTransactionResponse)

WithdrawRequest = _reflection.GeneratedProtocolMessageType('WithdrawRequest', (_message.Message,), {
  'DESCRIPTOR' : _WITHDRAWREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.WithdrawRequest)
  })
_sym_db.RegisterMessage(WithdrawRequest)

WithdrawResponse = _reflection.GeneratedProtocolMessageType('WithdrawResponse', (_message.Message,), {
  'DESCRIPTOR' : _WITHDRAWRESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.WithdrawResponse)
  })
_sym_db.RegisterMessage(WithdrawResponse)

NotifyTraderAccountRequest = _reflection.GeneratedProtocolMessageType('NotifyTraderAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFYTRADERACCOUNTREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.NotifyTraderAccountRequest)
  })
_sym_db.RegisterMessage(NotifyTraderAccountRequest)

NotifyTraderAccountResponse = _reflection.GeneratedProtocolMessageType('NotifyTraderAccountResponse', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFYTRADERACCOUNTRESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.NotifyTraderAccountResponse)
  })
_sym_db.RegisterMessage(NotifyTraderAccountResponse)

PrepareSubmitOrderResponse = _reflection.GeneratedProtocolMessageType('PrepareSubmitOrderResponse', (_message.Message,), {
  'DESCRIPTOR' : _PREPARESUBMITORDERRESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.PrepareSubmitOrderResponse)
  })
_sym_db.RegisterMessage(PrepareSubmitOrderResponse)

PrepareCancelOrderResponse = _reflection.GeneratedProtocolMessageType('PrepareCancelOrderResponse', (_message.Message,), {
  'DESCRIPTOR' : _PREPARECANCELORDERRESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.PrepareCancelOrderResponse)
  })
_sym_db.RegisterMessage(PrepareCancelOrderResponse)

PrepareAmendOrderResponse = _reflection.GeneratedProtocolMessageType('PrepareAmendOrderResponse', (_message.Message,), {
  'DESCRIPTOR' : _PREPAREAMENDORDERRESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.PrepareAmendOrderResponse)
  })
_sym_db.RegisterMessage(PrepareAmendOrderResponse)

SubmitOrderRequest = _reflection.GeneratedProtocolMessageType('SubmitOrderRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBMITORDERREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.SubmitOrderRequest)
  })
_sym_db.RegisterMessage(SubmitOrderRequest)

CancelOrderRequest = _reflection.GeneratedProtocolMessageType('CancelOrderRequest', (_message.Message,), {
  'DESCRIPTOR' : _CANCELORDERREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.CancelOrderRequest)
  })
_sym_db.RegisterMessage(CancelOrderRequest)

AmendOrderRequest = _reflection.GeneratedProtocolMessageType('AmendOrderRequest', (_message.Message,), {
  'DESCRIPTOR' : _AMENDORDERREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.AmendOrderRequest)
  })
_sym_db.RegisterMessage(AmendOrderRequest)

AssetsRequest = _reflection.GeneratedProtocolMessageType('AssetsRequest', (_message.Message,), {
  'DESCRIPTOR' : _ASSETSREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.AssetsRequest)
  })
_sym_db.RegisterMessage(AssetsRequest)

AssetsResponse = _reflection.GeneratedProtocolMessageType('AssetsResponse', (_message.Message,), {
  'DESCRIPTOR' : _ASSETSRESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.AssetsResponse)
  })
_sym_db.RegisterMessage(AssetsResponse)

AssetByIDRequest = _reflection.GeneratedProtocolMessageType('AssetByIDRequest', (_message.Message,), {
  'DESCRIPTOR' : _ASSETBYIDREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.AssetByIDRequest)
  })
_sym_db.RegisterMessage(AssetByIDRequest)

AssetByIDResponse = _reflection.GeneratedProtocolMessageType('AssetByIDResponse', (_message.Message,), {
  'DESCRIPTOR' : _ASSETBYIDRESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.AssetByIDResponse)
  })
_sym_db.RegisterMessage(AssetByIDResponse)

GetNodeSignaturesAggregateRequest = _reflection.GeneratedProtocolMessageType('GetNodeSignaturesAggregateRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNODESIGNATURESAGGREGATEREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.GetNodeSignaturesAggregateRequest)
  })
_sym_db.RegisterMessage(GetNodeSignaturesAggregateRequest)

GetNodeSignaturesAggregateResponse = _reflection.GeneratedProtocolMessageType('GetNodeSignaturesAggregateResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETNODESIGNATURESAGGREGATERESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.GetNodeSignaturesAggregateResponse)
  })
_sym_db.RegisterMessage(GetNodeSignaturesAggregateResponse)

OptionalProposalState = _reflection.GeneratedProtocolMessageType('OptionalProposalState', (_message.Message,), {
  'DESCRIPTOR' : _OPTIONALPROPOSALSTATE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.OptionalProposalState)
  })
_sym_db.RegisterMessage(OptionalProposalState)

GetProposalsRequest = _reflection.GeneratedProtocolMessageType('GetProposalsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPROPOSALSREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.GetProposalsRequest)
  })
_sym_db.RegisterMessage(GetProposalsRequest)

GetProposalsResponse = _reflection.GeneratedProtocolMessageType('GetProposalsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPROPOSALSRESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.GetProposalsResponse)
  })
_sym_db.RegisterMessage(GetProposalsResponse)

GetProposalsByPartyRequest = _reflection.GeneratedProtocolMessageType('GetProposalsByPartyRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPROPOSALSBYPARTYREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.GetProposalsByPartyRequest)
  })
_sym_db.RegisterMessage(GetProposalsByPartyRequest)

GetProposalsByPartyResponse = _reflection.GeneratedProtocolMessageType('GetProposalsByPartyResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPROPOSALSBYPARTYRESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.GetProposalsByPartyResponse)
  })
_sym_db.RegisterMessage(GetProposalsByPartyResponse)

GetVotesByPartyRequest = _reflection.GeneratedProtocolMessageType('GetVotesByPartyRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETVOTESBYPARTYREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.GetVotesByPartyRequest)
  })
_sym_db.RegisterMessage(GetVotesByPartyRequest)

GetVotesByPartyResponse = _reflection.GeneratedProtocolMessageType('GetVotesByPartyResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETVOTESBYPARTYRESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.GetVotesByPartyResponse)
  })
_sym_db.RegisterMessage(GetVotesByPartyResponse)

GetNewMarketProposalsRequest = _reflection.GeneratedProtocolMessageType('GetNewMarketProposalsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNEWMARKETPROPOSALSREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.GetNewMarketProposalsRequest)
  })
_sym_db.RegisterMessage(GetNewMarketProposalsRequest)

GetNewMarketProposalsResponse = _reflection.GeneratedProtocolMessageType('GetNewMarketProposalsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETNEWMARKETPROPOSALSRESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.GetNewMarketProposalsResponse)
  })
_sym_db.RegisterMessage(GetNewMarketProposalsResponse)

GetUpdateMarketProposalsRequest = _reflection.GeneratedProtocolMessageType('GetUpdateMarketProposalsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETUPDATEMARKETPROPOSALSREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.GetUpdateMarketProposalsRequest)
  })
_sym_db.RegisterMessage(GetUpdateMarketProposalsRequest)

GetUpdateMarketProposalsResponse = _reflection.GeneratedProtocolMessageType('GetUpdateMarketProposalsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETUPDATEMARKETPROPOSALSRESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.GetUpdateMarketProposalsResponse)
  })
_sym_db.RegisterMessage(GetUpdateMarketProposalsResponse)

GetNetworkParametersProposalsRequest = _reflection.GeneratedProtocolMessageType('GetNetworkParametersProposalsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNETWORKPARAMETERSPROPOSALSREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.GetNetworkParametersProposalsRequest)
  })
_sym_db.RegisterMessage(GetNetworkParametersProposalsRequest)

GetNetworkParametersProposalsResponse = _reflection.GeneratedProtocolMessageType('GetNetworkParametersProposalsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETNETWORKPARAMETERSPROPOSALSRESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.GetNetworkParametersProposalsResponse)
  })
_sym_db.RegisterMessage(GetNetworkParametersProposalsResponse)

GetNewAssetProposalsRequest = _reflection.GeneratedProtocolMessageType('GetNewAssetProposalsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNEWASSETPROPOSALSREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.GetNewAssetProposalsRequest)
  })
_sym_db.RegisterMessage(GetNewAssetProposalsRequest)

GetNewAssetProposalsResponse = _reflection.GeneratedProtocolMessageType('GetNewAssetProposalsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETNEWASSETPROPOSALSRESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.GetNewAssetProposalsResponse)
  })
_sym_db.RegisterMessage(GetNewAssetProposalsResponse)

GetProposalByIDRequest = _reflection.GeneratedProtocolMessageType('GetProposalByIDRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPROPOSALBYIDREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.GetProposalByIDRequest)
  })
_sym_db.RegisterMessage(GetProposalByIDRequest)

GetProposalByIDResponse = _reflection.GeneratedProtocolMessageType('GetProposalByIDResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPROPOSALBYIDRESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.GetProposalByIDResponse)
  })
_sym_db.RegisterMessage(GetProposalByIDResponse)

GetProposalByReferenceRequest = _reflection.GeneratedProtocolMessageType('GetProposalByReferenceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPROPOSALBYREFERENCEREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.GetProposalByReferenceRequest)
  })
_sym_db.RegisterMessage(GetProposalByReferenceRequest)

GetProposalByReferenceResponse = _reflection.GeneratedProtocolMessageType('GetProposalByReferenceResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPROPOSALBYREFERENCERESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.GetProposalByReferenceResponse)
  })
_sym_db.RegisterMessage(GetProposalByReferenceResponse)

ObservePartyProposalsRequest = _reflection.GeneratedProtocolMessageType('ObservePartyProposalsRequest', (_message.Message,), {
  'DESCRIPTOR' : _OBSERVEPARTYPROPOSALSREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.ObservePartyProposalsRequest)
  })
_sym_db.RegisterMessage(ObservePartyProposalsRequest)

ObserveProposalVotesRequest = _reflection.GeneratedProtocolMessageType('ObserveProposalVotesRequest', (_message.Message,), {
  'DESCRIPTOR' : _OBSERVEPROPOSALVOTESREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.ObserveProposalVotesRequest)
  })
_sym_db.RegisterMessage(ObserveProposalVotesRequest)

ObservePartyVotesRequest = _reflection.GeneratedProtocolMessageType('ObservePartyVotesRequest', (_message.Message,), {
  'DESCRIPTOR' : _OBSERVEPARTYVOTESREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.ObservePartyVotesRequest)
  })
_sym_db.RegisterMessage(ObservePartyVotesRequest)

MarginLevelsSubscribeRequest = _reflection.GeneratedProtocolMessageType('MarginLevelsSubscribeRequest', (_message.Message,), {
  'DESCRIPTOR' : _MARGINLEVELSSUBSCRIBEREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.MarginLevelsSubscribeRequest)
  })
_sym_db.RegisterMessage(MarginLevelsSubscribeRequest)

MarginLevelsRequest = _reflection.GeneratedProtocolMessageType('MarginLevelsRequest', (_message.Message,), {
  'DESCRIPTOR' : _MARGINLEVELSREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.MarginLevelsRequest)
  })
_sym_db.RegisterMessage(MarginLevelsRequest)

MarginLevelsResponse = _reflection.GeneratedProtocolMessageType('MarginLevelsResponse', (_message.Message,), {
  'DESCRIPTOR' : _MARGINLEVELSRESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.MarginLevelsResponse)
  })
_sym_db.RegisterMessage(MarginLevelsResponse)

MarketsDataSubscribeRequest = _reflection.GeneratedProtocolMessageType('MarketsDataSubscribeRequest', (_message.Message,), {
  'DESCRIPTOR' : _MARKETSDATASUBSCRIBEREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.MarketsDataSubscribeRequest)
  })
_sym_db.RegisterMessage(MarketsDataSubscribeRequest)

MarketDataByIDRequest = _reflection.GeneratedProtocolMessageType('MarketDataByIDRequest', (_message.Message,), {
  'DESCRIPTOR' : _MARKETDATABYIDREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.MarketDataByIDRequest)
  })
_sym_db.RegisterMessage(MarketDataByIDRequest)

MarketDataByIDResponse = _reflection.GeneratedProtocolMessageType('MarketDataByIDResponse', (_message.Message,), {
  'DESCRIPTOR' : _MARKETDATABYIDRESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.MarketDataByIDResponse)
  })
_sym_db.RegisterMessage(MarketDataByIDResponse)

MarketsDataResponse = _reflection.GeneratedProtocolMessageType('MarketsDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _MARKETSDATARESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.MarketsDataResponse)
  })
_sym_db.RegisterMessage(MarketsDataResponse)

LastTradeRequest = _reflection.GeneratedProtocolMessageType('LastTradeRequest', (_message.Message,), {
  'DESCRIPTOR' : _LASTTRADEREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.LastTradeRequest)
  })
_sym_db.RegisterMessage(LastTradeRequest)

LastTradeResponse = _reflection.GeneratedProtocolMessageType('LastTradeResponse', (_message.Message,), {
  'DESCRIPTOR' : _LASTTRADERESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.LastTradeResponse)
  })
_sym_db.RegisterMessage(LastTradeResponse)

MarketByIDRequest = _reflection.GeneratedProtocolMessageType('MarketByIDRequest', (_message.Message,), {
  'DESCRIPTOR' : _MARKETBYIDREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.MarketByIDRequest)
  })
_sym_db.RegisterMessage(MarketByIDRequest)

MarketByIDResponse = _reflection.GeneratedProtocolMessageType('MarketByIDResponse', (_message.Message,), {
  'DESCRIPTOR' : _MARKETBYIDRESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.MarketByIDResponse)
  })
_sym_db.RegisterMessage(MarketByIDResponse)

PartyByIDRequest = _reflection.GeneratedProtocolMessageType('PartyByIDRequest', (_message.Message,), {
  'DESCRIPTOR' : _PARTYBYIDREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.PartyByIDRequest)
  })
_sym_db.RegisterMessage(PartyByIDRequest)

PartyByIDResponse = _reflection.GeneratedProtocolMessageType('PartyByIDResponse', (_message.Message,), {
  'DESCRIPTOR' : _PARTYBYIDRESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.PartyByIDResponse)
  })
_sym_db.RegisterMessage(PartyByIDResponse)

PartiesResponse = _reflection.GeneratedProtocolMessageType('PartiesResponse', (_message.Message,), {
  'DESCRIPTOR' : _PARTIESRESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.PartiesResponse)
  })
_sym_db.RegisterMessage(PartiesResponse)

TradesByPartyRequest = _reflection.GeneratedProtocolMessageType('TradesByPartyRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRADESBYPARTYREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.TradesByPartyRequest)
  })
_sym_db.RegisterMessage(TradesByPartyRequest)

TradesByPartyResponse = _reflection.GeneratedProtocolMessageType('TradesByPartyResponse', (_message.Message,), {
  'DESCRIPTOR' : _TRADESBYPARTYRESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.TradesByPartyResponse)
  })
_sym_db.RegisterMessage(TradesByPartyResponse)

TradesByOrderRequest = _reflection.GeneratedProtocolMessageType('TradesByOrderRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRADESBYORDERREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.TradesByOrderRequest)
  })
_sym_db.RegisterMessage(TradesByOrderRequest)

TradesByOrderResponse = _reflection.GeneratedProtocolMessageType('TradesByOrderResponse', (_message.Message,), {
  'DESCRIPTOR' : _TRADESBYORDERRESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.TradesByOrderResponse)
  })
_sym_db.RegisterMessage(TradesByOrderResponse)

AccountsSubscribeRequest = _reflection.GeneratedProtocolMessageType('AccountsSubscribeRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTSSUBSCRIBEREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.AccountsSubscribeRequest)
  })
_sym_db.RegisterMessage(AccountsSubscribeRequest)

OrdersSubscribeRequest = _reflection.GeneratedProtocolMessageType('OrdersSubscribeRequest', (_message.Message,), {
  'DESCRIPTOR' : _ORDERSSUBSCRIBEREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.OrdersSubscribeRequest)
  })
_sym_db.RegisterMessage(OrdersSubscribeRequest)

TradesSubscribeRequest = _reflection.GeneratedProtocolMessageType('TradesSubscribeRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRADESSUBSCRIBEREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.TradesSubscribeRequest)
  })
_sym_db.RegisterMessage(TradesSubscribeRequest)

CandlesSubscribeRequest = _reflection.GeneratedProtocolMessageType('CandlesSubscribeRequest', (_message.Message,), {
  'DESCRIPTOR' : _CANDLESSUBSCRIBEREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.CandlesSubscribeRequest)
  })
_sym_db.RegisterMessage(CandlesSubscribeRequest)

MarketDepthSubscribeRequest = _reflection.GeneratedProtocolMessageType('MarketDepthSubscribeRequest', (_message.Message,), {
  'DESCRIPTOR' : _MARKETDEPTHSUBSCRIBEREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.MarketDepthSubscribeRequest)
  })
_sym_db.RegisterMessage(MarketDepthSubscribeRequest)

PositionsSubscribeRequest = _reflection.GeneratedProtocolMessageType('PositionsSubscribeRequest', (_message.Message,), {
  'DESCRIPTOR' : _POSITIONSSUBSCRIBEREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.PositionsSubscribeRequest)
  })
_sym_db.RegisterMessage(PositionsSubscribeRequest)

OrdersByMarketRequest = _reflection.GeneratedProtocolMessageType('OrdersByMarketRequest', (_message.Message,), {
  'DESCRIPTOR' : _ORDERSBYMARKETREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.OrdersByMarketRequest)
  })
_sym_db.RegisterMessage(OrdersByMarketRequest)

OrdersByMarketResponse = _reflection.GeneratedProtocolMessageType('OrdersByMarketResponse', (_message.Message,), {
  'DESCRIPTOR' : _ORDERSBYMARKETRESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.OrdersByMarketResponse)
  })
_sym_db.RegisterMessage(OrdersByMarketResponse)

OrdersByPartyRequest = _reflection.GeneratedProtocolMessageType('OrdersByPartyRequest', (_message.Message,), {
  'DESCRIPTOR' : _ORDERSBYPARTYREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.OrdersByPartyRequest)
  })
_sym_db.RegisterMessage(OrdersByPartyRequest)

OrdersByPartyResponse = _reflection.GeneratedProtocolMessageType('OrdersByPartyResponse', (_message.Message,), {
  'DESCRIPTOR' : _ORDERSBYPARTYRESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.OrdersByPartyResponse)
  })
_sym_db.RegisterMessage(OrdersByPartyResponse)

OrderByMarketAndIdRequest = _reflection.GeneratedProtocolMessageType('OrderByMarketAndIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _ORDERBYMARKETANDIDREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.OrderByMarketAndIdRequest)
  })
_sym_db.RegisterMessage(OrderByMarketAndIdRequest)

OrderByMarketAndIdResponse = _reflection.GeneratedProtocolMessageType('OrderByMarketAndIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _ORDERBYMARKETANDIDRESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.OrderByMarketAndIdResponse)
  })
_sym_db.RegisterMessage(OrderByMarketAndIdResponse)

OrderByReferenceRequest = _reflection.GeneratedProtocolMessageType('OrderByReferenceRequest', (_message.Message,), {
  'DESCRIPTOR' : _ORDERBYREFERENCEREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.OrderByReferenceRequest)
  })
_sym_db.RegisterMessage(OrderByReferenceRequest)

OrderByReferenceResponse = _reflection.GeneratedProtocolMessageType('OrderByReferenceResponse', (_message.Message,), {
  'DESCRIPTOR' : _ORDERBYREFERENCERESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.OrderByReferenceResponse)
  })
_sym_db.RegisterMessage(OrderByReferenceResponse)

MarketsResponse = _reflection.GeneratedProtocolMessageType('MarketsResponse', (_message.Message,), {
  'DESCRIPTOR' : _MARKETSRESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.MarketsResponse)
  })
_sym_db.RegisterMessage(MarketsResponse)

CandlesRequest = _reflection.GeneratedProtocolMessageType('CandlesRequest', (_message.Message,), {
  'DESCRIPTOR' : _CANDLESREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.CandlesRequest)
  })
_sym_db.RegisterMessage(CandlesRequest)

CandlesResponse = _reflection.GeneratedProtocolMessageType('CandlesResponse', (_message.Message,), {
  'DESCRIPTOR' : _CANDLESRESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.CandlesResponse)
  })
_sym_db.RegisterMessage(CandlesResponse)

MarketDepthRequest = _reflection.GeneratedProtocolMessageType('MarketDepthRequest', (_message.Message,), {
  'DESCRIPTOR' : _MARKETDEPTHREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.MarketDepthRequest)
  })
_sym_db.RegisterMessage(MarketDepthRequest)

MarketDepthResponse = _reflection.GeneratedProtocolMessageType('MarketDepthResponse', (_message.Message,), {
  'DESCRIPTOR' : _MARKETDEPTHRESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.MarketDepthResponse)
  })
_sym_db.RegisterMessage(MarketDepthResponse)

TradesByMarketRequest = _reflection.GeneratedProtocolMessageType('TradesByMarketRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRADESBYMARKETREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.TradesByMarketRequest)
  })
_sym_db.RegisterMessage(TradesByMarketRequest)

TradesByMarketResponse = _reflection.GeneratedProtocolMessageType('TradesByMarketResponse', (_message.Message,), {
  'DESCRIPTOR' : _TRADESBYMARKETRESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.TradesByMarketResponse)
  })
_sym_db.RegisterMessage(TradesByMarketResponse)

PositionsByPartyRequest = _reflection.GeneratedProtocolMessageType('PositionsByPartyRequest', (_message.Message,), {
  'DESCRIPTOR' : _POSITIONSBYPARTYREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.PositionsByPartyRequest)
  })
_sym_db.RegisterMessage(PositionsByPartyRequest)

PositionsByPartyResponse = _reflection.GeneratedProtocolMessageType('PositionsByPartyResponse', (_message.Message,), {
  'DESCRIPTOR' : _POSITIONSBYPARTYRESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.PositionsByPartyResponse)
  })
_sym_db.RegisterMessage(PositionsByPartyResponse)

VegaTimeResponse = _reflection.GeneratedProtocolMessageType('VegaTimeResponse', (_message.Message,), {
  'DESCRIPTOR' : _VEGATIMERESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.VegaTimeResponse)
  })
_sym_db.RegisterMessage(VegaTimeResponse)

Pagination = _reflection.GeneratedProtocolMessageType('Pagination', (_message.Message,), {
  'DESCRIPTOR' : _PAGINATION,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.Pagination)
  })
_sym_db.RegisterMessage(Pagination)

OrdersStream = _reflection.GeneratedProtocolMessageType('OrdersStream', (_message.Message,), {
  'DESCRIPTOR' : _ORDERSSTREAM,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.OrdersStream)
  })
_sym_db.RegisterMessage(OrdersStream)

TradesStream = _reflection.GeneratedProtocolMessageType('TradesStream', (_message.Message,), {
  'DESCRIPTOR' : _TRADESSTREAM,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.TradesStream)
  })
_sym_db.RegisterMessage(TradesStream)

PartyAccountsRequest = _reflection.GeneratedProtocolMessageType('PartyAccountsRequest', (_message.Message,), {
  'DESCRIPTOR' : _PARTYACCOUNTSREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.PartyAccountsRequest)
  })
_sym_db.RegisterMessage(PartyAccountsRequest)

PartyAccountsResponse = _reflection.GeneratedProtocolMessageType('PartyAccountsResponse', (_message.Message,), {
  'DESCRIPTOR' : _PARTYACCOUNTSRESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.PartyAccountsResponse)
  })
_sym_db.RegisterMessage(PartyAccountsResponse)

MarketAccountsRequest = _reflection.GeneratedProtocolMessageType('MarketAccountsRequest', (_message.Message,), {
  'DESCRIPTOR' : _MARKETACCOUNTSREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.MarketAccountsRequest)
  })
_sym_db.RegisterMessage(MarketAccountsRequest)

MarketAccountsResponse = _reflection.GeneratedProtocolMessageType('MarketAccountsResponse', (_message.Message,), {
  'DESCRIPTOR' : _MARKETACCOUNTSRESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.MarketAccountsResponse)
  })
_sym_db.RegisterMessage(MarketAccountsResponse)

PrepareProposalRequest = _reflection.GeneratedProtocolMessageType('PrepareProposalRequest', (_message.Message,), {
  'DESCRIPTOR' : _PREPAREPROPOSALREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.PrepareProposalRequest)
  })
_sym_db.RegisterMessage(PrepareProposalRequest)

PrepareProposalResponse = _reflection.GeneratedProtocolMessageType('PrepareProposalResponse', (_message.Message,), {
  'DESCRIPTOR' : _PREPAREPROPOSALRESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.PrepareProposalResponse)
  })
_sym_db.RegisterMessage(PrepareProposalResponse)

PrepareVoteRequest = _reflection.GeneratedProtocolMessageType('PrepareVoteRequest', (_message.Message,), {
  'DESCRIPTOR' : _PREPAREVOTEREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.PrepareVoteRequest)
  })
_sym_db.RegisterMessage(PrepareVoteRequest)

PrepareVoteResponse = _reflection.GeneratedProtocolMessageType('PrepareVoteResponse', (_message.Message,), {
  'DESCRIPTOR' : _PREPAREVOTERESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.PrepareVoteResponse)
  })
_sym_db.RegisterMessage(PrepareVoteResponse)

OrderByIDRequest = _reflection.GeneratedProtocolMessageType('OrderByIDRequest', (_message.Message,), {
  'DESCRIPTOR' : _ORDERBYIDREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.OrderByIDRequest)
  })
_sym_db.RegisterMessage(OrderByIDRequest)

OrderByReferenceIDRequest = _reflection.GeneratedProtocolMessageType('OrderByReferenceIDRequest', (_message.Message,), {
  'DESCRIPTOR' : _ORDERBYREFERENCEIDREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.OrderByReferenceIDRequest)
  })
_sym_db.RegisterMessage(OrderByReferenceIDRequest)

OrderVersionsByIDRequest = _reflection.GeneratedProtocolMessageType('OrderVersionsByIDRequest', (_message.Message,), {
  'DESCRIPTOR' : _ORDERVERSIONSBYIDREQUEST,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.OrderVersionsByIDRequest)
  })
_sym_db.RegisterMessage(OrderVersionsByIDRequest)

OrderVersionsResponse = _reflection.GeneratedProtocolMessageType('OrderVersionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _ORDERVERSIONSRESPONSE,
  '__module__' : 'proto.api.trading_pb2'
  # @@protoc_insertion_point(class_scope:api.OrderVersionsResponse)
  })
_sym_db.RegisterMessage(OrderVersionsResponse)


DESCRIPTOR._options = None
_GETPROPOSALSBYPARTYREQUEST.fields_by_name['partyID']._options = None
_GETVOTESBYPARTYREQUEST.fields_by_name['partyID']._options = None
_GETUPDATEMARKETPROPOSALSREQUEST.fields_by_name['marketID']._options = None
_GETPROPOSALBYIDREQUEST.fields_by_name['proposalID']._options = None
_GETPROPOSALBYREFERENCEREQUEST.fields_by_name['Reference']._options = None
_OBSERVEPARTYPROPOSALSREQUEST.fields_by_name['partyID']._options = None
_OBSERVEPROPOSALVOTESREQUEST.fields_by_name['proposalID']._options = None
_OBSERVEPARTYVOTESREQUEST.fields_by_name['partyID']._options = None
_MARGINLEVELSSUBSCRIBEREQUEST.fields_by_name['partyID']._options = None
_MARGINLEVELSREQUEST.fields_by_name['partyID']._options = None
_MARKETDATABYIDREQUEST.fields_by_name['marketID']._options = None
_LASTTRADEREQUEST.fields_by_name['marketID']._options = None
_MARKETBYIDREQUEST.fields_by_name['marketID']._options = None
_PARTYBYIDREQUEST.fields_by_name['partyID']._options = None
_CANDLESSUBSCRIBEREQUEST.fields_by_name['marketID']._options = None
_MARKETDEPTHSUBSCRIBEREQUEST.fields_by_name['marketID']._options = None
_ORDERSBYMARKETREQUEST.fields_by_name['marketID']._options = None
_ORDERSBYPARTYREQUEST.fields_by_name['partyID']._options = None
_ORDERBYMARKETANDIDREQUEST.fields_by_name['marketID']._options = None
_ORDERBYMARKETANDIDREQUEST.fields_by_name['orderID']._options = None
_ORDERBYREFERENCEREQUEST.fields_by_name['reference']._options = None
_CANDLESREQUEST.fields_by_name['marketID']._options = None
_CANDLESREQUEST.fields_by_name['sinceTimestamp']._options = None
_MARKETDEPTHREQUEST.fields_by_name['marketID']._options = None
_TRADESBYMARKETREQUEST.fields_by_name['marketID']._options = None
_POSITIONSBYPARTYREQUEST.fields_by_name['partyID']._options = None
_PREPAREPROPOSALREQUEST.fields_by_name['partyID']._options = None
_PREPAREPROPOSALREQUEST.fields_by_name['proposal']._options = None
_PREPAREVOTEREQUEST.fields_by_name['vote']._options = None
_ORDERBYIDREQUEST.fields_by_name['orderID']._options = None
_ORDERBYREFERENCEIDREQUEST.fields_by_name['referenceID']._options = None
_ORDERVERSIONSBYIDREQUEST.fields_by_name['orderID']._options = None

_TRADING = _descriptor.ServiceDescriptor(
  name='trading',
  full_name='api.trading',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=6530,
  serialized_end=7241,
  methods=[
  _descriptor.MethodDescriptor(
    name='PrepareSubmitOrder',
    full_name='api.trading.PrepareSubmitOrder',
    index=0,
    containing_service=None,
    input_type=_SUBMITORDERREQUEST,
    output_type=_PREPARESUBMITORDERRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='PrepareCancelOrder',
    full_name='api.trading.PrepareCancelOrder',
    index=1,
    containing_service=None,
    input_type=_CANCELORDERREQUEST,
    output_type=_PREPARECANCELORDERRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='PrepareAmendOrder',
    full_name='api.trading.PrepareAmendOrder',
    index=2,
    containing_service=None,
    input_type=_AMENDORDERREQUEST,
    output_type=_PREPAREAMENDORDERRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyTraderAccount',
    full_name='api.trading.NotifyTraderAccount',
    index=3,
    containing_service=None,
    input_type=_NOTIFYTRADERACCOUNTREQUEST,
    output_type=_NOTIFYTRADERACCOUNTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Withdraw',
    full_name='api.trading.Withdraw',
    index=4,
    containing_service=None,
    input_type=_WITHDRAWREQUEST,
    output_type=_WITHDRAWRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SubmitTransaction',
    full_name='api.trading.SubmitTransaction',
    index=5,
    containing_service=None,
    input_type=_SUBMITTRANSACTIONREQUEST,
    output_type=_SUBMITTRANSACTIONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='PrepareProposal',
    full_name='api.trading.PrepareProposal',
    index=6,
    containing_service=None,
    input_type=_PREPAREPROPOSALREQUEST,
    output_type=_PREPAREPROPOSALRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='PrepareVote',
    full_name='api.trading.PrepareVote',
    index=7,
    containing_service=None,
    input_type=_PREPAREVOTEREQUEST,
    output_type=_PREPAREVOTERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='PropagateChainEvent',
    full_name='api.trading.PropagateChainEvent',
    index=8,
    containing_service=None,
    input_type=_PROPAGATECHAINEVENTREQUEST,
    output_type=_PROPAGATECHAINEVENTRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_TRADING)

DESCRIPTOR.services_by_name['trading'] = _TRADING


_TRADING_DATA = _descriptor.ServiceDescriptor(
  name='trading_data',
  full_name='api.trading_data',
  file=DESCRIPTOR,
  index=1,
  serialized_options=None,
  serialized_start=7244,
  serialized_end=10965,
  methods=[
  _descriptor.MethodDescriptor(
    name='MarketAccounts',
    full_name='api.trading_data.MarketAccounts',
    index=0,
    containing_service=None,
    input_type=_MARKETACCOUNTSREQUEST,
    output_type=_MARKETACCOUNTSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='PartyAccounts',
    full_name='api.trading_data.PartyAccounts',
    index=1,
    containing_service=None,
    input_type=_PARTYACCOUNTSREQUEST,
    output_type=_PARTYACCOUNTSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Candles',
    full_name='api.trading_data.Candles',
    index=2,
    containing_service=None,
    input_type=_CANDLESREQUEST,
    output_type=_CANDLESRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='MarketDataByID',
    full_name='api.trading_data.MarketDataByID',
    index=3,
    containing_service=None,
    input_type=_MARKETDATABYIDREQUEST,
    output_type=_MARKETDATABYIDRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='MarketsData',
    full_name='api.trading_data.MarketsData',
    index=4,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_MARKETSDATARESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='MarketByID',
    full_name='api.trading_data.MarketByID',
    index=5,
    containing_service=None,
    input_type=_MARKETBYIDREQUEST,
    output_type=_MARKETBYIDRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='MarketDepth',
    full_name='api.trading_data.MarketDepth',
    index=6,
    containing_service=None,
    input_type=_MARKETDEPTHREQUEST,
    output_type=_MARKETDEPTHRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Markets',
    full_name='api.trading_data.Markets',
    index=7,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_MARKETSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='OrderByMarketAndID',
    full_name='api.trading_data.OrderByMarketAndID',
    index=8,
    containing_service=None,
    input_type=_ORDERBYMARKETANDIDREQUEST,
    output_type=_ORDERBYMARKETANDIDRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='OrderByReference',
    full_name='api.trading_data.OrderByReference',
    index=9,
    containing_service=None,
    input_type=_ORDERBYREFERENCEREQUEST,
    output_type=_ORDERBYREFERENCERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='OrdersByMarket',
    full_name='api.trading_data.OrdersByMarket',
    index=10,
    containing_service=None,
    input_type=_ORDERSBYMARKETREQUEST,
    output_type=_ORDERSBYMARKETRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='OrdersByParty',
    full_name='api.trading_data.OrdersByParty',
    index=11,
    containing_service=None,
    input_type=_ORDERSBYPARTYREQUEST,
    output_type=_ORDERSBYPARTYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='OrderByID',
    full_name='api.trading_data.OrderByID',
    index=12,
    containing_service=None,
    input_type=_ORDERBYIDREQUEST,
    output_type=proto_dot_vega__pb2._ORDER,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='OrderByReferenceID',
    full_name='api.trading_data.OrderByReferenceID',
    index=13,
    containing_service=None,
    input_type=_ORDERBYREFERENCEIDREQUEST,
    output_type=proto_dot_vega__pb2._ORDER,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='OrderVersionsByID',
    full_name='api.trading_data.OrderVersionsByID',
    index=14,
    containing_service=None,
    input_type=_ORDERVERSIONSBYIDREQUEST,
    output_type=_ORDERVERSIONSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='MarginLevels',
    full_name='api.trading_data.MarginLevels',
    index=15,
    containing_service=None,
    input_type=_MARGINLEVELSREQUEST,
    output_type=_MARGINLEVELSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Parties',
    full_name='api.trading_data.Parties',
    index=16,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_PARTIESRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='PartyByID',
    full_name='api.trading_data.PartyByID',
    index=17,
    containing_service=None,
    input_type=_PARTYBYIDREQUEST,
    output_type=_PARTYBYIDRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='PositionsByParty',
    full_name='api.trading_data.PositionsByParty',
    index=18,
    containing_service=None,
    input_type=_POSITIONSBYPARTYREQUEST,
    output_type=_POSITIONSBYPARTYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='LastTrade',
    full_name='api.trading_data.LastTrade',
    index=19,
    containing_service=None,
    input_type=_LASTTRADEREQUEST,
    output_type=_LASTTRADERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='TradesByMarket',
    full_name='api.trading_data.TradesByMarket',
    index=20,
    containing_service=None,
    input_type=_TRADESBYMARKETREQUEST,
    output_type=_TRADESBYMARKETRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='TradesByOrder',
    full_name='api.trading_data.TradesByOrder',
    index=21,
    containing_service=None,
    input_type=_TRADESBYORDERREQUEST,
    output_type=_TRADESBYORDERRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='TradesByParty',
    full_name='api.trading_data.TradesByParty',
    index=22,
    containing_service=None,
    input_type=_TRADESBYPARTYREQUEST,
    output_type=_TRADESBYPARTYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetProposals',
    full_name='api.trading_data.GetProposals',
    index=23,
    containing_service=None,
    input_type=_GETPROPOSALSREQUEST,
    output_type=_GETPROPOSALSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetProposalsByParty',
    full_name='api.trading_data.GetProposalsByParty',
    index=24,
    containing_service=None,
    input_type=_GETPROPOSALSBYPARTYREQUEST,
    output_type=_GETPROPOSALSBYPARTYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetVotesByParty',
    full_name='api.trading_data.GetVotesByParty',
    index=25,
    containing_service=None,
    input_type=_GETVOTESBYPARTYREQUEST,
    output_type=_GETVOTESBYPARTYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetNewMarketProposals',
    full_name='api.trading_data.GetNewMarketProposals',
    index=26,
    containing_service=None,
    input_type=_GETNEWMARKETPROPOSALSREQUEST,
    output_type=_GETNEWMARKETPROPOSALSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetUpdateMarketProposals',
    full_name='api.trading_data.GetUpdateMarketProposals',
    index=27,
    containing_service=None,
    input_type=_GETUPDATEMARKETPROPOSALSREQUEST,
    output_type=_GETUPDATEMARKETPROPOSALSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetNetworkParametersProposals',
    full_name='api.trading_data.GetNetworkParametersProposals',
    index=28,
    containing_service=None,
    input_type=_GETNETWORKPARAMETERSPROPOSALSREQUEST,
    output_type=_GETNETWORKPARAMETERSPROPOSALSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetNewAssetProposals',
    full_name='api.trading_data.GetNewAssetProposals',
    index=29,
    containing_service=None,
    input_type=_GETNEWASSETPROPOSALSREQUEST,
    output_type=_GETNEWASSETPROPOSALSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetProposalByID',
    full_name='api.trading_data.GetProposalByID',
    index=30,
    containing_service=None,
    input_type=_GETPROPOSALBYIDREQUEST,
    output_type=_GETPROPOSALBYIDRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetProposalByReference',
    full_name='api.trading_data.GetProposalByReference',
    index=31,
    containing_service=None,
    input_type=_GETPROPOSALBYREFERENCEREQUEST,
    output_type=_GETPROPOSALBYREFERENCERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ObserveGovernance',
    full_name='api.trading_data.ObserveGovernance',
    index=32,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=proto_dot_governance__pb2._GOVERNANCEDATA,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ObservePartyProposals',
    full_name='api.trading_data.ObservePartyProposals',
    index=33,
    containing_service=None,
    input_type=_OBSERVEPARTYPROPOSALSREQUEST,
    output_type=proto_dot_governance__pb2._GOVERNANCEDATA,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ObservePartyVotes',
    full_name='api.trading_data.ObservePartyVotes',
    index=34,
    containing_service=None,
    input_type=_OBSERVEPARTYVOTESREQUEST,
    output_type=proto_dot_governance__pb2._VOTE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ObserveProposalVotes',
    full_name='api.trading_data.ObserveProposalVotes',
    index=35,
    containing_service=None,
    input_type=_OBSERVEPROPOSALVOTESREQUEST,
    output_type=proto_dot_governance__pb2._VOTE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Statistics',
    full_name='api.trading_data.Statistics',
    index=36,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=proto_dot_vega__pb2._STATISTICS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetVegaTime',
    full_name='api.trading_data.GetVegaTime',
    index=37,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_VEGATIMERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AccountsSubscribe',
    full_name='api.trading_data.AccountsSubscribe',
    index=38,
    containing_service=None,
    input_type=_ACCOUNTSSUBSCRIBEREQUEST,
    output_type=proto_dot_vega__pb2._ACCOUNT,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CandlesSubscribe',
    full_name='api.trading_data.CandlesSubscribe',
    index=39,
    containing_service=None,
    input_type=_CANDLESSUBSCRIBEREQUEST,
    output_type=proto_dot_vega__pb2._CANDLE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='MarginLevelsSubscribe',
    full_name='api.trading_data.MarginLevelsSubscribe',
    index=40,
    containing_service=None,
    input_type=_MARGINLEVELSSUBSCRIBEREQUEST,
    output_type=proto_dot_vega__pb2._MARGINLEVELS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='MarketDepthSubscribe',
    full_name='api.trading_data.MarketDepthSubscribe',
    index=41,
    containing_service=None,
    input_type=_MARKETDEPTHSUBSCRIBEREQUEST,
    output_type=proto_dot_vega__pb2._MARKETDEPTH,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='MarketsDataSubscribe',
    full_name='api.trading_data.MarketsDataSubscribe',
    index=42,
    containing_service=None,
    input_type=_MARKETSDATASUBSCRIBEREQUEST,
    output_type=proto_dot_vega__pb2._MARKETDATA,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='OrdersSubscribe',
    full_name='api.trading_data.OrdersSubscribe',
    index=43,
    containing_service=None,
    input_type=_ORDERSSUBSCRIBEREQUEST,
    output_type=_ORDERSSTREAM,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='PositionsSubscribe',
    full_name='api.trading_data.PositionsSubscribe',
    index=44,
    containing_service=None,
    input_type=_POSITIONSSUBSCRIBEREQUEST,
    output_type=proto_dot_vega__pb2._POSITION,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='TradesSubscribe',
    full_name='api.trading_data.TradesSubscribe',
    index=45,
    containing_service=None,
    input_type=_TRADESSUBSCRIBEREQUEST,
    output_type=_TRADESSTREAM,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='TransferResponsesSubscribe',
    full_name='api.trading_data.TransferResponsesSubscribe',
    index=46,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=proto_dot_vega__pb2._TRANSFERRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetNodeSignaturesAggregate',
    full_name='api.trading_data.GetNodeSignaturesAggregate',
    index=47,
    containing_service=None,
    input_type=_GETNODESIGNATURESAGGREGATEREQUEST,
    output_type=_GETNODESIGNATURESAGGREGATERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AssetByID',
    full_name='api.trading_data.AssetByID',
    index=48,
    containing_service=None,
    input_type=_ASSETBYIDREQUEST,
    output_type=_ASSETBYIDRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Assets',
    full_name='api.trading_data.Assets',
    index=49,
    containing_service=None,
    input_type=_ASSETSREQUEST,
    output_type=_ASSETSRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_TRADING_DATA)

DESCRIPTOR.services_by_name['trading_data'] = _TRADING_DATA

# @@protoc_insertion_point(module_scope)
